@@ -1,7 +1,7 @@
 #
 #  - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 #  SLEPc - Scalable Library for Eigenvalue Problem Computations
-#  Copyright (c) 2002-2019, Universitat Politecnica de Valencia, Spain
+#  Copyright (c) 2002-2020, Universitat Politecnica de Valencia, Spain
 #
 #  This file is part of SLEPc.
 #  SLEPc is distributed under a 2-clause BSD license (see LICENSE).
@@ -22,6 +22,7 @@ class Arpack(package.Package):
     self.archive        = 'arpack-ng-'+self.version+'.tar.gz'
     self.dirname        = 'arpack-ng-'+self.version
     self.supportssingle = True
+    self.supports64bint = True
     self.fortran        = True
     self.ProcessArgs(argdb)
 
@@ -51,7 +52,7 @@ class Arpack(package.Package):
     return functions
 
 
-  def Check(self,conf,vars,petsc):
+  def Check(self,conf,vars,petsc,archdir):
     functions = self.Functions(petsc)
     if self.packagelibs:
       libs = [self.packagelibs]
@@ -62,33 +63,34 @@ class Arpack(package.Package):
         libs = [['-lparpack','-larpack'],['-lparpack_MPI','-larpack'],['-lparpack_MPI-LINUX','-larpack_LINUX'],['-lparpack_MPI-SUN4','-larpack_SUN4']]
 
     if self.packagedir:
-      dirs = [self.packagedir]
+      dirs = [os.path.join(self.packagedir,'lib'),self.packagedir]
     else:
-      dirs = self.GenerateGuesses('Arpack')
-
+      dirs = self.GenerateGuesses('Arpack',archdir)
     self.FortranLib(conf,vars,dirs,libs,functions)
 
 
-  def Install(self,conf,vars,petsc,archdir):
-    externdir = os.path.join(archdir,'externalpackages')
-    builddir  = os.path.join(externdir,self.dirname)
-    self.Download(externdir,builddir)
+  def DownloadAndInstall(self,conf,vars,slepc,petsc,archdir,prefixdir):
+    externdir = slepc.CreateDir(archdir,'externalpackages')
+    builddir  = self.Download(externdir,slepc.downloaddir)
 
     # Check for autoreconf
-    result,output = self.RunCommand('autoreconf --help')
+    (result,output) = self.RunCommand('autoreconf --help')
     if result:
-      self.log.Exit('ERROR: --download-arpack requires that the command autoreconf is available on your PATH.')
+      self.log.Exit('--download-arpack requires that the command autoreconf is available on your PATH')
 
     # Build package
-    confopt = '--prefix='+archdir+' CC="'+petsc.cc+'" CFLAGS="'+petsc.cc_flags+'" F77="'+petsc.fc+'" FFLAGS="'+petsc.fc_flags.replace('-Wall','').replace('-Wshadow','')+'"'
+    confopt = '--prefix='+prefixdir+' CC="'+petsc.cc+'" CFLAGS="'+petsc.cc_flags+'" F77="'+petsc.fc+'" FFLAGS="'+petsc.fc_flags.replace('-Wall','').replace('-Wshadow','')+'" FC="'+petsc.fc+'" FCFLAGS="'+petsc.fc_flags.replace('-Wall','').replace('-Wshadow','')+'"'
     if not petsc.mpiuni:
-      confopt = confopt+' --enable-mpi'
+      confopt = confopt+' --enable-mpi MPICC="'+petsc.cc+'" MPIF77="'+petsc.fc+'" MPIFC="'+petsc.fc+'"'
     if not petsc.buildsharedlib:
       confopt = confopt+' --disable-shared'
-    result,output = self.RunCommand('cd '+builddir+'&& sh bootstrap && ./configure '+confopt+' && '+petsc.make+' && '+petsc.make+' install')
-    self.log.write(output)
+    if petsc.ind64:
+      if not petsc.blaslapackint64:
+        self.log.Exit('To install ARPACK with 64-bit integers you also need a BLAS with 64-bit integers')
+      confopt = confopt+' INTERFACE64=1'
+    (result,output) = self.RunCommand('cd '+builddir+'&& sh bootstrap && ./configure '+confopt+' && '+petsc.make+' && '+petsc.make+' install')
     if result:
-      self.log.Exit('ERROR: installation of ARPACK failed.')
+      self.log.Exit('Installation of ARPACK failed')
 
     # Check build
     functions = self.Functions(petsc)
@@ -96,8 +98,7 @@ class Arpack(package.Package):
       libs = [['-larpack']]
     else:
       libs = [['-lparpack','-larpack']]
-    libDir = os.path.join(archdir,'lib')
-    dirs = [libDir]
+    libdir = os.path.join(prefixdir,'lib')
+    dirs = [libdir]
     self.FortranLib(conf,vars,dirs,libs,functions)
-    self.havepackage = True
 
