@@ -1,14 +1,14 @@
 #
 #  - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 #  SLEPc - Scalable Library for Eigenvalue Problem Computations
-#  Copyright (c) 2002-2019, Universitat Politecnica de Valencia, Spain
+#  Copyright (c) 2002-2020, Universitat Politecnica de Valencia, Spain
 #
 #  This file is part of SLEPc.
 #  SLEPc is distributed under a 2-clause BSD license (see LICENSE).
 #  - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 #
 
-import log, package
+import os, log, package
 
 class Blzpack(package.Package):
 
@@ -20,7 +20,7 @@ class Blzpack(package.Package):
     self.supportssingle = True
     self.ProcessArgs(argdb)
 
-  def Check(self,conf,vars,petsc):
+  def Check(self,conf,vars,petsc,archdir):
     if petsc.precision == 'single':
       functions = ['blzdrs']
     else:
@@ -32,9 +32,9 @@ class Blzpack(package.Package):
       libs = [['-lblzpack']]
 
     if self.packagedir:
-      dirs = [self.packagedir]
+      dirs = [os.path.join(self.packagedir,'lib'),self.packagedir]
     else:
-      dirs = self.GenerateGuesses('Blzpack')
+      dirs = self.GenerateGuesses('Blzpack',archdir)
 
     self.FortranLib(conf,vars,dirs,libs,functions)
 
