@@ -1,7 +1,7 @@
 #
 #  - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 #  SLEPc - Scalable Library for Eigenvalue Problem Computations
-#  Copyright (c) 2002-2019, Universitat Politecnica de Valencia, Spain
+#  Copyright (c) 2002-2020, Universitat Politecnica de Valencia, Spain
 #
 #  This file is part of SLEPc.
 #  SLEPc is distributed under a 2-clause BSD license (see LICENSE).
@@ -17,19 +17,20 @@ class PETSc(package.Package):
     self.packagename = 'petsc'
 
   def Check(self):
-    self.havepackage = self.Link([],[],[])
+    (result, output) = self.Link([],[],[])
+    self.havepackage = result
 
   def InitDir(self,prefixdir):
     if 'PETSC_DIR' in os.environ:
       self.dir = os.environ['PETSC_DIR']
       if not os.path.exists(self.dir):
-        sys.exit('ERROR: PETSC_DIR enviroment variable is not valid')
+        self.log.Exit('PETSC_DIR enviroment variable is not valid')
     else:
       if prefixdir:
         self.dir = prefixdir
         os.environ['PETSC_DIR'] = self.dir
       else:
-        sys.exit('ERROR: PETSC_DIR enviroment variable is not set')
+        self.log.Exit('PETSC_DIR enviroment variable is not set')
 
   def LoadVersion(self):
     try:
@@ -50,7 +51,7 @@ class PETSc(package.Package):
       self.lversion = major + '.' + minor + '.' + subminor
       self.nversion = int(major)*100 + int(minor)
     except:
-      self.log.Exit('ERROR: File error while reading PETSc version')
+      self.log.Exit('File error while reading PETSc version')
 
     # Check whether this is a working copy of the repository
     self.isrepo = False
@@ -58,16 +59,18 @@ class PETSc(package.Package):
       (status, output) = self.RunCommand('cd '+self.dir+';git rev-parse')
       if not status:
         self.isrepo = True
-        (status, self.gitrev) = self.RunCommand('cd '+self.dir+';git log -1 --pretty=format:%H')
+        (status, self.gitrev)  = self.RunCommand('cd '+self.dir+';git log -1 --pretty=format:%H')
         (status, self.gitdate) = self.RunCommand('cd '+self.dir+';git log -1 --pretty=format:%ci')
-        (status, self.branch) = self.RunCommand('cd '+self.dir+';git describe --contains --all HEAD')
+        (status, self.branch)  = self.RunCommand('cd '+self.dir+';git describe --contains --all HEAD')
 
   def LoadConf(self):
     if 'PETSC_ARCH' in os.environ and os.environ['PETSC_ARCH']:
       self.isinstall = False
       self.arch = os.environ['PETSC_ARCH']
       if os.path.basename(self.arch) != self.arch:
-        self.log.Exit(('ERROR: variable PETSC_ARCH must not be a full path\nYou set PETSC_ARCH=%s\nMaybe you meant PETSC_ARCH=%s'% (self.arch,os.path.basename(self.arch))))
+        suggest = os.path.basename(self.arch)
+        if not suggest: suggest = os.path.basename(self.arch[0:-1])
+        self.log.Exit('Variable PETSC_ARCH must not be a full path\nYou set PETSC_ARCH=%s, maybe you meant PETSC_ARCH=%s'% (self.arch,suggest))
       petscvariables = os.path.join(self.dir,self.arch,'lib','petsc','conf','petscvariables')
       petscconf_h = os.path.join(self.dir,self.arch,'include','petscconf.h')
     else:
@@ -76,7 +79,6 @@ class PETSc(package.Package):
       petscconf_h = os.path.join(self.dir,'include','petscconf.h')
 
     self.buildsharedlib = False
-    self.language = 'c'
     self.bfort = 'nobfortinpetsc'
     try:
       f = open(petscvariables)
@@ -85,6 +87,7 @@ class PETSc(package.Package):
         if len(r)!=2: continue
         k = r[0].strip()
         v = r[1].strip()
+        v = v.replace('${PETSC_DIR}',self.dir)  # needed in some Cray installations
         if k == 'PETSC_SCALAR':
           self.scalar = v
         elif k == 'PETSC_PRECISION':
@@ -99,6 +102,10 @@ class PETSc(package.Package):
           self.cc = v
         elif k == 'CC_FLAGS':
           self.cc_flags = v
+        elif k == 'CXX':
+          self.cxx = v
+        elif k == 'CXX_FLAGS':
+          self.cxx_flags = v
         elif k == 'FC' and not v=='':
           self.fc = v
         elif k == 'FC_FLAGS':
@@ -117,11 +124,9 @@ class PETSc(package.Package):
           self.sl_suffix = v
         elif k == 'RANLIB':
           self.ranlib = v
-        elif k == 'PETSC_LANGUAGE' and v=='CXXONLY':
-          self.language = 'c++'
       f.close()
     except:
-      self.log.Exit('ERROR: cannot process file ' + petscvariables)
+      self.log.Exit('Cannot process file ' + petscvariables)
 
     self.ind64 = False
     self.mpiuni = False
@@ -130,6 +135,9 @@ class PETSc(package.Package):
     self.blaslapackmangling = ''
     self.blaslapackint64 = False
     self.fortran = False
+    self.language = 'c'
+    self.cxxdialectcxx11 = False
+    self.hpddm = False
     try:
       f = open(petscconf_h)
       for l in f.readlines():
@@ -146,18 +154,22 @@ class PETSc(package.Package):
           self.blaslapackmangling = 'underscore'
         elif len(l)==3 and l[0]=='#define' and l[1]=='PETSC_BLASLAPACK_CAPS' and l[2]=='1':
           self.blaslapackmangling = 'caps'
-        elif len(l)==3 and l[0]=='#define' and l[1]=='PETSC_BLASLAPACK_STDCALL' and l[2]=='1':
-          self.blaslapackmangling = 'stdcall'
         elif len(l)==3 and l[0]=='#define' and l[1]=='PETSC_HAVE_64BIT_BLAS_INDICES' and l[2]=='1':
           self.blaslapackint64 = True
         elif len(l)==3 and l[0]=='#define' and l[1]=='PETSC_HAVE_FORTRAN' and l[2]=='1':
           self.fortran = True
+        elif len(l)==3 and l[0]=='#define' and l[1]=='PETSC_CLANGUAGE_CXX' and l[2]=='1':
+          self.language = 'c++'
+        elif len(l)==3 and l[0]=='#define' and l[1]=='PETSC_HAVE_CXX_DIALECT_CXX11' and l[2]=='1':
+          self.cxxdialectcxx11 = True
+        elif len(l)==3 and l[0]=='#define' and l[1]=='PETSC_HAVE_HPDDM' and l[2]=='1':
+          self.hpddm = True
         elif self.isinstall and len(l)==3 and l[0]=='#define' and l[1]=='PETSC_ARCH':
           self.arch = l[2].strip('"')
       f.close()
     except:
       if self.isinstall:
-        self.log.Exit('ERROR: cannot process file ' + petscconf_h + ', maybe you forgot to set PETSC_ARCH')
+        self.log.Exit('Cannot process file ' + petscconf_h + ', maybe you forgot to set PETSC_ARCH')
       else:
-        self.log.Exit('ERROR: cannot process file ' + petscconf_h)
+        self.log.Exit('Cannot process file ' + petscconf_h)
 
