@@ -1,7 +1,7 @@
 #
 #  - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 #  SLEPc - Scalable Library for Eigenvalue Problem Computations
-#  Copyright (c) 2002-2019, Universitat Politecnica de Valencia, Spain
+#  Copyright (c) 2002-2020, Universitat Politecnica de Valencia, Spain
 #
 #  This file is part of SLEPc.
 #  SLEPc is distributed under a 2-clause BSD license (see LICENSE).
@@ -16,7 +16,6 @@ class Slicot(package.Package):
     package.Package.__init__(self,argdb,log)
     self.packagename    = 'slicot'
     self.installable    = True
-    self.downloadable   = True
     self.version        = '4.5'
     self.url            = 'http://slicot.org/objects/software/shared/slicot45.tar.gz'
     self.archive        = 'slicot45.tar.gz'
@@ -26,25 +25,24 @@ class Slicot(package.Package):
     self.ProcessArgs(argdb)
 
 
-  def Check(self,conf,vars,petsc):
-    functions = ['sb03od']
+  def Check(self,conf,vars,petsc,archdir):
+    functions = ['sb03od','sb03md']
     if self.packagelibs:
       libs = [self.packagelibs]
     else:
       libs = [['-lslicot']]
 
     if self.packagedir:
-      dirs = [self.packagedir]
+      dirs = [os.path.join(self.packagedir,'lib'),self.packagedir]
     else:
-      dirs = self.GenerateGuesses('slicot')
+      dirs = self.GenerateGuesses('slicot',archdir)
 
     self.FortranLib(conf,vars,dirs,libs,functions)
 
 
-  def Install(self,conf,vars,petsc,archdir):
-    externdir = os.path.join(archdir,'externalpackages')
-    builddir  = os.path.join(externdir,self.dirname)
-    self.Download(externdir,builddir)
+  def DownloadAndInstall(self,conf,vars,slepc,petsc,archdir,prefixdir):
+    externdir = slepc.CreateDir(archdir,'externalpackages')
+    builddir  = self.Download(externdir,slepc.downloaddir)
     libname = 'libslicot.a'
 
     # Configure
@@ -58,20 +56,17 @@ class Slicot(package.Package):
 
     # Build package
     target = 'lib'
-    result,output = self.RunCommand('cd '+builddir+'&&'+petsc.make+' clean &&'+petsc.make+' '+target)
-    self.log.write(output)
+    (result,output) = self.RunCommand('cd '+builddir+'&&'+petsc.make+' clean &&'+petsc.make+' '+target)
     if result:
-      self.log.Exit('ERROR: installation of SLICOT failed.')
+      self.log.Exit('Installation of SLICOT failed')
 
     # Move files
-    libDir = os.path.join(archdir,'lib')
-    os.rename(os.path.join(builddir,libname),os.path.join(libDir,libname))
+    incdir,libdir = slepc.CreatePrefixDirs(prefixdir)
+    os.rename(os.path.join(builddir,libname),os.path.join(libdir,libname))
 
     # Check build
     functions = ['sb03od']
     libs = [['-lslicot']]
-    libDir = os.path.join(archdir,'lib')
-    dirs = [libDir]
+    dirs = [libdir]
     self.FortranLib(conf,vars,dirs,libs,functions)
-    self.havepackage = True
 
