@@ -1,7 +1,7 @@
 #
 #  - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 #  SLEPc - Scalable Library for Eigenvalue Problem Computations
-#  Copyright (c) 2002-2019, Universitat Politecnica de Valencia, Spain
+#  Copyright (c) 2002-2020, Universitat Politecnica de Valencia, Spain
 #
 #  This file is part of SLEPc.
 #  SLEPc is distributed under a 2-clause BSD license (see LICENSE).
@@ -25,7 +25,7 @@ class Trlan(package.Package):
     self.fortran        = True
     self.ProcessArgs(argdb)
 
-  def Check(self,conf,vars,petsc):
+  def Check(self,conf,vars,petsc,archdir):
     functions = ['trlan77']
     if self.packagelibs:
       libs = [self.packagelibs]
@@ -36,17 +36,16 @@ class Trlan(package.Package):
         libs = [['-ltrlan_mpi']]
 
     if self.packagedir:
-      dirs = [self.packagedir]
+      dirs = [os.path.join(self.packagedir,'lib'),self.packagedir]
     else:
-      dirs = self.GenerateGuesses('TRLan')
+      dirs = self.GenerateGuesses('TRLan',archdir)
 
     self.FortranLib(conf,vars,dirs,libs,functions)
 
 
-  def Install(self,conf,vars,petsc,archdir):
-    externdir = os.path.join(archdir,'externalpackages')
-    builddir  = os.path.join(externdir,self.dirname)
-    self.Download(externdir,builddir)
+  def DownloadAndInstall(self,conf,vars,slepc,petsc,archdir,prefixdir):
+    externdir = slepc.CreateDir(archdir,'externalpackages')
+    builddir  = self.Download(externdir,slepc.downloaddir)
 
     # Configure
     g = open(os.path.join(builddir,'Make.inc'),'w')
@@ -61,18 +60,17 @@ class Trlan(package.Package):
       target = 'lib'
     else:
       target = 'plib'
-    result,output = self.RunCommand('cd '+builddir+'&&'+petsc.make+' clean &&'+petsc.make+' '+target)
-    self.log.write(output)
+    (result,output) = self.RunCommand('cd '+builddir+'&&'+petsc.make+' clean &&'+petsc.make+' '+target)
     if result:
-      self.log.Exit('ERROR: installation of TRLAN failed.')
+      self.log.Exit('Installation of TRLAN failed')
 
     # Move files
-    libDir = os.path.join(archdir,'lib')
+    incdir,libdir = slepc.CreatePrefixDirs(prefixdir)
     if petsc.mpiuni:
       libName = 'libtrlan.a'
     else:
       libName = 'libtrlan_mpi.a'
-    os.rename(os.path.join(builddir,libName),os.path.join(libDir,libName))
+    os.rename(os.path.join(builddir,libName),os.path.join(libdir,libName))
 
     # Check build
     functions = ['trlan77']
@@ -80,8 +78,6 @@ class Trlan(package.Package):
       libs = [['-ltrlan']]
     else:
       libs = [['-ltrlan_mpi']]
-    libDir = os.path.join(archdir,'lib')
-    dirs = [libDir]
+    dirs = [libdir]
     self.FortranLib(conf,vars,dirs,libs,functions)
-    self.havepackage = True
 
