@@ -1,7 +1,7 @@
 /*
    - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
    SLEPc - Scalable Library for Eigenvalue Problem Computations
-   Copyright (c) 2002-2019, Universitat Politecnica de Valencia, Spain
+   Copyright (c) 2002-2020, Universitat Politecnica de Valencia, Spain
 
    This file is part of SLEPc.
    SLEPc is distributed under a 2-clause BSD license (see LICENSE).
@@ -96,8 +96,6 @@ struct _p_BV {
   PetscRandom        rand;         /* random number generator */
   Mat                Acreate;      /* matrix given at BVCreateFromMat() */
   Mat                Aget;         /* matrix returned for BVGetMat() */
-  Mat                Amult;        /* matrix argument of last call to BVMatMult() */
-  PetscObjectState   Amultstate;   /* state of Amult */
   PetscBool          cuda;         /* true if GPU must be used in SVEC */
   PetscScalar        *work;
   PetscInt           lwork;
@@ -122,7 +120,7 @@ PETSC_STATIC_INLINE PetscErrorCode BV_SafeSqrt(BV bv,PetscScalar alpha,PetscReal
     ierr = PetscInfo(bv,"Zero norm, either the vector is zero or a semi-inner product is being used\n");CHKERRQ(ierr);
   }
 #if defined(PETSC_USE_COMPLEX)
-  if (PetscAbsReal(PetscImaginaryPart(alpha))>PETSC_MACHINE_EPSILON && PetscAbsReal(PetscImaginaryPart(alpha))/absal>100*PETSC_MACHINE_EPSILON) SETERRQ1(PetscObjectComm((PetscObject)bv),1,"The inner product is not well defined: nonzero imaginary part %g",PetscImaginaryPart(alpha));
+  if (PetscAbsReal(PetscImaginaryPart(alpha))>10*PETSC_MACHINE_EPSILON && PetscAbsReal(PetscImaginaryPart(alpha))/absal>100*PETSC_MACHINE_EPSILON) SETERRQ1(PetscObjectComm((PetscObject)bv),1,"The inner product is not well defined: nonzero imaginary part %g",PetscImaginaryPart(alpha));
 #endif
   if (bv->indef) {
     *res = (realp<0.0)? -PetscSqrtReal(-realp): PetscSqrtReal(realp);
@@ -227,12 +225,18 @@ PETSC_STATIC_INLINE PetscErrorCode BV_AllocateSignature(BV bv)
 #if !defined(PETSC_USE_DEBUG)
 
 #define BVCheckSizes(h,arg) do {} while (0)
+#define BVCheckOp(h,arg,op) do {} while (0)
 
 #else
 
 #define BVCheckSizes(h,arg) \
   do { \
-    if (!h->m) SETERRQ1(PetscObjectComm((PetscObject)h),PETSC_ERR_ARG_WRONGSTATE,"BV sizes have not been defined: Parameter #%d",arg); \
+    if (!(h)->m) SETERRQ1(PetscObjectComm((PetscObject)(h)),PETSC_ERR_ARG_WRONGSTATE,"BV sizes have not been defined: Parameter #%d",arg); \
+  } while (0)
+
+#define BVCheckOp(h,arg,op) \
+  do { \
+    if (!(h)->ops->op) SETERRQ1(PetscObjectComm((PetscObject)(h)),PETSC_ERR_SUP,"Operation not implemented in this BV type: Parameter #%d",arg); \
   } while (0)
 
 #endif
@@ -258,13 +262,9 @@ SLEPC_INTERN PetscErrorCode BVOrthogonalize_LAPACK_TSQR_OnlyR(BV,PetscInt,PetscI
 
 /* reduction operation used in BVOrthogonalize */
 SLEPC_EXTERN MPI_Op MPIU_TSQR;
-SLEPC_EXTERN void SlepcGivensPacked(void*,void*,PetscMPIInt*,MPI_Datatype*);
+SLEPC_EXTERN void MPIAPI SlepcGivensPacked(void*,void*,PetscMPIInt*,MPI_Datatype*);
 
 #if defined(PETSC_HAVE_CUDA)
-#include <petsccuda.h>
-#include <cublas_v2.h>
-
-#define WaitForGPU() PetscCUDASynchronize ? cudaDeviceSynchronize() : 0
 
 /* complex single */
 #if defined(PETSC_USE_COMPLEX)
@@ -476,6 +476,28 @@ PETSC_STATIC_INLINE PetscErrorCode BV_GetEigenvector(BV V,PetscInt k,PetscScalar
   PetscFunctionReturn(0);
 }
 
+/*
+   BV_OrthogonalizeColumn_Safe - this is intended for cases where we know that
+   the resulting vector is going to be numerically zero, so normalization or
+   iterative refinement may cause problems in parallel (collective operation
+   not being called by all processes)
+*/
+PETSC_STATIC_INLINE PetscErrorCode BV_OrthogonalizeColumn_Safe(BV bv,PetscInt j,PetscScalar *H,PetscReal *norm,PetscBool *lindep)
+{
+  PetscErrorCode     ierr;
+  BVOrthogRefineType orthog_ref;
+
+  PetscFunctionBegin;
+  ierr = PetscInfo1(bv,"Orthogonalizing column %D without refinement\n",j);CHKERRQ(ierr);
+  orthog_ref     = bv->orthog_ref;
+  bv->orthog_ref = BV_ORTHOG_REFINE_NEVER;  /* avoid refinement */
+  ierr = BVOrthogonalizeColumn(bv,j,H,NULL,NULL);CHKERRQ(ierr);
+  bv->orthog_ref = orthog_ref;  /* restore refinement setting */
+  if (norm)   *norm  = 0.0;
+  if (lindep) *lindep = PETSC_TRUE;
+  PetscFunctionReturn(0);
+}
+
 #if defined(PETSC_HAVE_CUDA)
 #define BV_CleanCoefficients(a,b,c)   ((a)->cuda?BV_CleanCoefficients_CUDA:BV_CleanCoefficients_Default)((a),(b),(c))
 #define BV_AddCoefficients(a,b,c,d)   ((a)->cuda?BV_AddCoefficients_CUDA:BV_AddCoefficients_Default)((a),(b),(c),(d))
