@@ -1,7 +1,7 @@
 /*
    - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
    SLEPc - Scalable Library for Eigenvalue Problem Computations
-   Copyright (c) 2002-2019, Universitat Politecnica de Valencia, Spain
+   Copyright (c) 2002-2020, Universitat Politecnica de Valencia, Spain
 
    This file is part of SLEPc.
    SLEPc is distributed under a 2-clause BSD license (see LICENSE).
@@ -57,28 +57,31 @@ SLEPC_EXTERN PetscErrorCode STGetMatrix(ST,PetscInt,Mat*);
 SLEPC_EXTERN PetscErrorCode STGetMatrixTransformed(ST,PetscInt,Mat*);
 SLEPC_EXTERN PetscErrorCode STGetNumMatrices(ST,PetscInt*);
 SLEPC_EXTERN PetscErrorCode STGetOperator(ST,Mat*);
+SLEPC_EXTERN PetscErrorCode STRestoreOperator(ST,Mat*);
 SLEPC_EXTERN PetscErrorCode STSetUp(ST);
 SLEPC_EXTERN PetscErrorCode STSetFromOptions(ST);
 SLEPC_EXTERN PetscErrorCode STView(ST,PetscViewer);
+SLEPC_EXTERN PetscErrorCode STViewFromOptions(ST,PetscObject,const char[]);
 
-PETSC_DEPRECATED("Use STSetMatrices()") PETSC_STATIC_INLINE PetscErrorCode STSetOperators(ST st,PetscInt n,Mat *A) {return STSetMatrices(st,n,A);}
-PETSC_DEPRECATED("Use STGetMatrix()") PETSC_STATIC_INLINE PetscErrorCode STGetOperators(ST st,PetscInt k,Mat *A) {return STGetMatrix(st,k,A);}
-PETSC_DEPRECATED("Use STGetMatrixTransformed()") PETSC_STATIC_INLINE PetscErrorCode STGetTOperators(ST st,PetscInt k,Mat *A) {return STGetMatrixTransformed(st,k,A);}
-PETSC_DEPRECATED("Use STGetOperator() followed by MatComputeExplicitOperator()") PETSC_STATIC_INLINE PetscErrorCode STComputeExplicitOperator(ST st,Mat *A) {
-  PetscErrorCode ierr; Mat Op; 
+PETSC_DEPRECATED_FUNCTION("Use STSetMatrices()") PETSC_STATIC_INLINE PetscErrorCode STSetOperators(ST st,PetscInt n,Mat *A) {return STSetMatrices(st,n,A);}
+PETSC_DEPRECATED_FUNCTION("Use STGetMatrix()") PETSC_STATIC_INLINE PetscErrorCode STGetOperators(ST st,PetscInt k,Mat *A) {return STGetMatrix(st,k,A);}
+PETSC_DEPRECATED_FUNCTION("Use STGetMatrixTransformed()") PETSC_STATIC_INLINE PetscErrorCode STGetTOperators(ST st,PetscInt k,Mat *A) {return STGetMatrixTransformed(st,k,A);}
+PETSC_DEPRECATED_FUNCTION("Use STGetOperator() followed by MatComputeOperator()") PETSC_STATIC_INLINE PetscErrorCode STComputeExplicitOperator(ST st,Mat *A) {
+  PetscErrorCode ierr; Mat Op;
   ierr = STGetOperator(st,&Op);CHKERRQ(ierr);
-  ierr = MatComputeExplicitOperator(Op,A);CHKERRQ(ierr);
-  ierr = MatDestroy(&Op);CHKERRQ(ierr);
+  ierr = MatComputeOperator(Op,MATAIJ,A);CHKERRQ(ierr);
+  ierr = STRestoreOperator(st,&Op);CHKERRQ(ierr);
   PetscFunctionReturn(0);
 }
 
 SLEPC_EXTERN PetscErrorCode STApply(ST,Vec,Vec);
+SLEPC_EXTERN PetscErrorCode STApplyTranspose(ST,Vec,Vec);
+SLEPC_EXTERN PetscErrorCode STApplyHermitianTranspose(ST,Vec,Vec);
 SLEPC_EXTERN PetscErrorCode STMatMult(ST,PetscInt,Vec,Vec);
 SLEPC_EXTERN PetscErrorCode STMatMultTranspose(ST,PetscInt,Vec,Vec);
 SLEPC_EXTERN PetscErrorCode STMatSolve(ST,Vec,Vec);
 SLEPC_EXTERN PetscErrorCode STMatSolveTranspose(ST,Vec,Vec);
 SLEPC_EXTERN PetscErrorCode STGetBilinearForm(ST,Mat*);
-SLEPC_EXTERN PetscErrorCode STApplyTranspose(ST,Vec,Vec);
 SLEPC_EXTERN PetscErrorCode STMatSetUp(ST,PetscScalar,PetscScalar*);
 SLEPC_EXTERN PetscErrorCode STPostSolve(ST);
 SLEPC_EXTERN PetscErrorCode STResetMatrixState(ST);
