@@ -1,7 +1,7 @@
 /*
    - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
    SLEPc - Scalable Library for Eigenvalue Problem Computations
-   Copyright (c) 2002-2019, Universitat Politecnica de Valencia, Spain
+   Copyright (c) 2002-2020, Universitat Politecnica de Valencia, Spain
 
    This file is part of SLEPc.
    SLEPc is distributed under a 2-clause BSD license (see LICENSE).
@@ -43,7 +43,7 @@ PetscErrorCode EPSSetUp_RQCG(EPS eps)
   PetscFunctionBegin;
   if (!eps->ishermitian || (eps->isgeneralized && !eps->ispositive)) SETERRQ(PetscObjectComm((PetscObject)eps),PETSC_ERR_SUP,"RQCG only works for Hermitian problems");
   ierr = EPSSetDimensions_Default(eps,eps->nev,&eps->ncv,&eps->mpd);CHKERRQ(ierr);
-  if (!eps->max_it) eps->max_it = PetscMax(100,2*eps->n/eps->ncv);
+  if (eps->max_it==PETSC_DEFAULT) eps->max_it = PetscMax(100,2*eps->n/eps->ncv);
   if (!eps->which) eps->which = EPS_SMALLEST_REAL;
   if (eps->which!=EPS_SMALLEST_REAL) SETERRQ(PetscObjectComm((PetscObject)eps),1,"Wrong value of eps->which");
   if (!eps->extraction) {
@@ -214,7 +214,7 @@ PetscErrorCode EPSSolve_RQCG(EPS eps)
       /* Search direction */
       for (i=0;i<nv-eps->nconv;i++) {
         ierr = BVGetColumn(ctx->G,i,&v);CHKERRQ(ierr);
-        ierr = STMatSolve(eps->st,v,w);CHKERRQ(ierr);
+        ierr = STApply(eps->st,v,w);CHKERRQ(ierr);
         ierr = VecDot(w,v,&g);CHKERRQ(ierr);
         ierr = BVRestoreColumn(ctx->G,i,&v);CHKERRQ(ierr);
         beta = (!reset && eps->its>1)? g/gamma[i]: 0.0;
