@@ -1,7 +1,7 @@
 /*
    - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
    SLEPc - Scalable Library for Eigenvalue Problem Computations
-   Copyright (c) 2002-2019, Universitat Politecnica de Valencia, Spain
+   Copyright (c) 2002-2020, Universitat Politecnica de Valencia, Spain
 
    This file is part of SLEPc.
    SLEPc is distributed under a 2-clause BSD license (see LICENSE).
@@ -19,7 +19,7 @@
    References:
 
        [1] "Arnoldi Methods in SLEPc", SLEPc Technical Report STR-4,
-           available at http://slepc.upv.es.
+           available at https://slepc.upv.es.
 */
 
 #include <slepc/private/epsimpl.h>                /*I "slepceps.h" I*/
@@ -35,7 +35,7 @@ PetscErrorCode EPSSetUp_Arnoldi(EPS eps)
   PetscFunctionBegin;
   ierr = EPSSetDimensions_Default(eps,eps->nev,&eps->ncv,&eps->mpd);CHKERRQ(ierr);
   if (eps->ncv>eps->nev+eps->mpd) SETERRQ(PetscObjectComm((PetscObject)eps),1,"The value of ncv must not be larger than nev+mpd");
-  if (!eps->max_it) eps->max_it = PetscMax(100,2*eps->n/eps->ncv);
+  if (eps->max_it==PETSC_DEFAULT) eps->max_it = PetscMax(100,2*eps->n/eps->ncv);
   if (!eps->which) { ierr = EPSSetWhichEigenpairs_Default(eps);CHKERRQ(ierr); }
   if (eps->which==EPS_ALL || (eps->ishermitian && eps->ispositive && (eps->which==EPS_LARGEST_IMAGINARY || eps->which==EPS_SMALLEST_IMAGINARY))) SETERRQ(PetscObjectComm((PetscObject)eps),1,"Wrong value of eps->which");
 
@@ -61,7 +61,7 @@ PetscErrorCode EPSSolve_Arnoldi(EPS eps)
 {
   PetscErrorCode     ierr;
   PetscInt           k,nv,ld;
-  Mat                U;
+  Mat                U,Op;
   PetscScalar        *H;
   PetscReal          beta,gamma=1.0;
   PetscBool          breakdown,harmonic,refined;
@@ -86,7 +86,9 @@ PetscErrorCode EPSSolve_Arnoldi(EPS eps)
     ierr = DSSetDimensions(eps->ds,nv,0,eps->nconv,0);CHKERRQ(ierr);
     ierr = DSGetArray(eps->ds,DS_MAT_A,&H);CHKERRQ(ierr);
     if (!arnoldi->delayed) {
-      ierr = EPSBasicArnoldi(eps,PETSC_FALSE,H,ld,eps->nconv,&nv,&beta,&breakdown);CHKERRQ(ierr);
+      ierr = STGetOperator(eps->st,&Op);CHKERRQ(ierr);
+      ierr = BVMatArnoldi(eps->V,Op,H,ld,eps->nconv,&nv,&beta,&breakdown);CHKERRQ(ierr);
+      ierr = STRestoreOperator(eps->st,&Op);CHKERRQ(ierr);
     } else if (orthog_ref == BV_ORTHOG_REFINE_NEVER) {
       ierr = EPSDelayedArnoldi1(eps,H,ld,eps->nconv,&nv,&beta,&breakdown);CHKERRQ(ierr);
     } else {
