@@ -1,7 +1,7 @@
 /*
    - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
    SLEPc - Scalable Library for Eigenvalue Problem Computations
-   Copyright (c) 2002-2019, Universitat Politecnica de Valencia, Spain
+   Copyright (c) 2002-2020, Universitat Politecnica de Valencia, Spain
 
    This file is part of SLEPc.
    SLEPc is distributed under a 2-clause BSD license (see LICENSE).
@@ -320,7 +320,7 @@ static PetscErrorCode EPSSliceGetInertia(EPS eps,PetscReal shift,PetscInt *inert
   KSP            ksp;
   PC             pc;
   Mat            F;
-  PetscReal      nzshift;
+  PetscReal      nzshift=shift;
 
   PetscFunctionBegin;
   if (shift >= PETSC_MAX_REAL) { /* Right-open interval */
@@ -334,12 +334,12 @@ static PetscErrorCode EPSSliceGetInertia(EPS eps,PetscReal shift,PetscInt *inert
        the symbolic factorizations */
     nzshift = (shift==0.0)? 10.0/PETSC_MAX_REAL: shift;
     ierr = STSetShift(eps->st,nzshift);CHKERRQ(ierr);
-    ierr = STSetUp(eps->st);CHKERRQ(ierr);
     ierr = STGetKSP(eps->st,&ksp);CHKERRQ(ierr);
     ierr = KSPGetPC(ksp,&pc);CHKERRQ(ierr);
     ierr = PCFactorGetMatrix(pc,&F);CHKERRQ(ierr);
     ierr = MatGetInertia(F,inertia,zeros,NULL);CHKERRQ(ierr);
   }
+  if (inertia) { ierr = PetscInfo2(eps,"Computed inertia at shift %g: %D\n",(double)nzshift,*inertia);CHKERRQ(ierr); }
   PetscFunctionReturn(0);
 }
 
@@ -358,13 +358,12 @@ PetscErrorCode EPSSetUp_KrylovSchur_Slice(EPS eps)
   PetscBool       issinv;
   EPS_KRYLOVSCHUR *ctx = (EPS_KRYLOVSCHUR*)eps->data,*ctx_glob;
   EPS_SR          sr,sr_loc,sr_glob;
-  PetscInt        nEigs,dssz=1,i,zeros=0,off=0,method;
+  PetscInt        nEigs,dssz=1,i,zeros=0,off=0,method,hiteig=0;
   PetscMPIInt     nproc,rank=0,aux;
   PetscReal       r;
   MPI_Request     req;
   Mat             A,B=NULL;
   SlepcSC         sc;
-  PetscInt        flg=0;
   DSParallelType  ptype;
 
   PetscFunctionBegin;
@@ -375,7 +374,7 @@ PetscErrorCode EPSSetUp_KrylovSchur_Slice(EPS eps)
     ierr = PetscObjectTypeCompareAny((PetscObject)eps->st,&issinv,STSINVERT,STCAYLEY,"");CHKERRQ(ierr);
     if (!issinv) SETERRQ(PetscObjectComm((PetscObject)eps),PETSC_ERR_SUP,"Shift-and-invert or Cayley ST is needed for spectrum slicing");
     if (eps->tol==PETSC_DEFAULT) eps->tol = SLEPC_DEFAULT_TOL*1e-2;  /* use tighter tolerance */
-    if (!eps->max_it) eps->max_it = 100;
+    if (eps->max_it==PETSC_DEFAULT) eps->max_it = 100;
     if (ctx->nev==1) ctx->nev = PetscMin(40,eps->n);  /* nev not set, use default value */
     if (eps->n>10 && ctx->nev<10) SETERRQ(PetscObjectComm((PetscObject)eps),PETSC_ERR_ARG_WRONG,"nev cannot be less than 10 in spectrum slicing runs");
   }
@@ -463,15 +462,23 @@ PetscErrorCode EPSSetUp_KrylovSchur_Slice(EPS eps)
       if ((sr->dir>0&&ctx->subc->color==ctx->npart-1)||(sr->dir<0&&ctx->subc->color==0)) sr->hasEnd = sr_glob->hasEnd;
       else sr->hasEnd = PETSC_TRUE;
     }
+    ierr = STSetUp(eps->st);CHKERRQ(ierr);
 
     /* compute inertia0 */
     ierr = EPSSliceGetInertia(eps,sr->int0,&sr->inertia0,ctx->detect?&zeros:NULL);CHKERRQ(ierr);
-    ierr = PetscOptionsGetInt(NULL,NULL,"-eps_krylovschur_hiteigenvalue",&flg,NULL);CHKERRQ(ierr);
+    /* undocumented option to control what to do when an eigenvalue is found:
+       - error out if it's the endpoint of the user-provided interval (or sub-interval)
+       - if it's an endpoint computed internally:
+          + if hiteig=0 error out
+          + else if hiteig=1 the subgroup that hit the eigenvalue does nothing
+          + otherwise the subgroup that hit the eigenvalue perturbs the shift and recomputes inertia
+    */
+    ierr = PetscOptionsGetInt(NULL,NULL,"-eps_krylovschur_hiteigenvalue",&hiteig,NULL);CHKERRQ(ierr);
     if (zeros) { /* error in factorization */
       if (sr->int0==ctx->eps->inta || sr->int0==ctx->eps->intb) SETERRQ(((PetscObject)eps)->comm,PETSC_ERR_USER,"Found singular matrix for the transformed problem in the interval endpoint");
-      else if (ctx_glob->subintset && !flg) SETERRQ(((PetscObject)eps)->comm,PETSC_ERR_USER,"Found singular matrix for the transformed problem in an interval endpoint defined by user");
+      else if (ctx_glob->subintset && !hiteig) SETERRQ(((PetscObject)eps)->comm,PETSC_ERR_USER,"Found singular matrix for the transformed problem in an interval endpoint defined by user");
       else {
-        if (flg==1) { /* idle subgroup */
+        if (hiteig==1) { /* idle subgroup */
           sr->inertia0 = -1;
         } else { /* perturb shift */
           sr->int0 *= (1.0+SLICE_PTOL);
@@ -794,6 +801,10 @@ static PetscErrorCode EPSCreateShift(EPS eps,PetscReal val,EPS_shift neighb0,EPS
 
   PetscFunctionBegin;
   sr = ctx->sr;
+  if ((neighb0 && val==neighb0->value) || (neighb1 && val==neighb1->value)) {
+    sr->nPend++;
+    PetscFunctionReturn(0);
+  }
   ierr = PetscNewLog(eps,&s);CHKERRQ(ierr);
   s->value = val;
   s->neighb[0] = neighb0;
@@ -871,18 +882,27 @@ static PetscErrorCode EPSExtractShift(EPS eps)
   PetscInt        iner,zeros=0;
   EPS_KRYLOVSCHUR *ctx=(EPS_KRYLOVSCHUR*)eps->data;
   EPS_SR          sr;
-  PetscReal       newShift;
+  PetscReal       newShift,diam,ptol;
   EPS_shift       sPres;
 
   PetscFunctionBegin;
   sr = ctx->sr;
   if (sr->nPend > 0) {
+    if (sr->sPres==sr->pending[sr->nPend-1]) {
+      eps->reason = EPS_CONVERGED_ITERATING;
+      eps->its = 0;
+      sr->nPend--;
+      sr->sPres->rep = PETSC_TRUE;
+      PetscFunctionReturn(0);
+    }
     sr->sPrev = sr->sPres;
     sr->sPres = sr->pending[--sr->nPend];
     sPres = sr->sPres;
     ierr = EPSSliceGetInertia(eps,sPres->value,&iner,ctx->detect?&zeros:NULL);CHKERRQ(ierr);
     if (zeros) {
-      newShift = sPres->value*(1.0+SLICE_PTOL);
+      diam = PetscMin(PetscAbsReal(sPres->neighb[0]->value-sPres->value),PetscAbsReal(sPres->neighb[1]->value-sPres->value));
+      ptol = PetscMin(SLICE_PTOL,diam/2);
+      newShift = sPres->value*(1.0+ptol);
       if (sr->dir*(sPres->neighb[0] && newShift-sPres->neighb[0]->value) < 0) newShift = (sPres->value+sPres->neighb[0]->value)/2;
       else if (sPres->neighb[1] && sr->dir*(sPres->neighb[1]->value-newShift) < 0) newShift = (sPres->value+sPres->neighb[1]->value)/2;
       ierr = EPSSliceGetInertia(eps,newShift,&iner,&zeros);CHKERRQ(ierr);
@@ -906,18 +926,15 @@ static PetscErrorCode EPSKrylovSchur_Slice(EPS eps)
 {
   PetscErrorCode  ierr;
   EPS_KRYLOVSCHUR *ctx=(EPS_KRYLOVSCHUR*)eps->data;
-  PetscInt        i,k,l,ld,nv,*iwork,j;
-  Mat             U;
+  PetscInt        i,k,l,ld,nv,*iwork,j,count0,count1,iterCompl=0,n0,n1;
+  Mat             U,Op;
   PetscScalar     *Q,*A;
-  PetscReal       *a,*b,beta;
-  PetscBool       breakdown;
-  PetscInt        count0,count1;
-  PetscReal       lambda;
+  PetscReal       *a,*b,beta,lambda;
   EPS_shift       sPres;
-  PetscBool       complIterating;
-  PetscBool       sch0,sch1;
-  PetscInt        iterCompl=0,n0,n1;
+  PetscBool       breakdown,complIterating,sch0,sch1;
   EPS_SR          sr = ctx->sr;
+#define MSGLEN 100
+  char            messg[MSGLEN];
 
   PetscFunctionBegin;
   /* Spectrum slicing data */
@@ -927,7 +944,7 @@ static PetscErrorCode EPSKrylovSchur_Slice(EPS eps)
   ierr = DSGetLeadingDimension(eps->ds,&ld);CHKERRQ(ierr);
   ierr = PetscMalloc1(2*ld,&iwork);CHKERRQ(ierr);
   count0=0;count1=0; /* Found on both sides */
-  if (sr->nS > 0 && (sPres->neighb[0] == sr->sPrev || sPres->neighb[1] == sr->sPrev)) {
+  if (!sPres->rep && sr->nS > 0 && (sPres->neighb[0] == sr->sPrev || sPres->neighb[1] == sr->sPrev)) {
     /* Rational Krylov */
     ierr = DSTranslateRKS(eps->ds,sr->sPrev->value-sPres->value);CHKERRQ(ierr);
     ierr = DSGetDimensions(eps->ds,NULL,NULL,NULL,&l,NULL);CHKERRQ(ierr);
@@ -948,7 +965,9 @@ static PetscErrorCode EPSKrylovSchur_Slice(EPS eps)
     nv = PetscMin(eps->nconv+eps->mpd,eps->ncv);
     ierr = DSGetArrayReal(eps->ds,DS_MAT_T,&a);CHKERRQ(ierr);
     b = a + ld;
-    ierr = EPSFullLanczos(eps,a,b,eps->nconv+l,&nv,&breakdown);CHKERRQ(ierr);
+    ierr = STGetOperator(eps->st,&Op);CHKERRQ(ierr);
+    ierr = BVMatLanczos(eps->V,Op,a,b,eps->nconv+l,&nv,&breakdown);CHKERRQ(ierr);
+    ierr = STRestoreOperator(eps->st,&Op);CHKERRQ(ierr);
     sr->nv = nv;
     beta = b[nv-1];
     ierr = DSRestoreArrayReal(eps->ds,DS_MAT_T,&a);CHKERRQ(ierr);
@@ -1075,6 +1094,8 @@ static PetscErrorCode EPSKrylovSchur_Slice(EPS eps)
   }
   sPres->comp[0] = PetscNot(count0 < sPres->nsch[0]);
   sPres->comp[1] = PetscNot(count1 < sPres->nsch[1]);
+  ierr = PetscSNPrintf(messg,MSGLEN,"Lanczos: %D evals in [%g,%g]%s and %D evals in [%g,%g]%s\n",count0,(double)(sr->dir==1)?sPres->ext[0]:sPres->value,(double)(sr->dir==1)?sPres->value:sPres->ext[0],(sPres->comp[0])?"*":"",count1,(double)(sr->dir==1)?sPres->value:sPres->ext[1],(double)(sr->dir==1)?sPres->ext[1]:sPres->value,(sPres->comp[1])?"*":"");CHKERRQ(ierr);
+  ierr = PetscInfo(eps,messg);CHKERRQ(ierr);
   if (count0 > sPres->nsch[0] || count1 > sPres->nsch[1]) InertiaMismatch(eps,ctx->detect);
   ierr = PetscFree(iwork);CHKERRQ(ierr);
   PetscFunctionReturn(0);
@@ -1095,11 +1116,9 @@ static PetscErrorCode EPSGetNewShiftValue(EPS eps,PetscInt side,PetscReal *newS)
   sr = ctx->sr;
   sPres = sr->sPres;
   if (sPres->neighb[side]) {
-  /* Completing a previous interval */
-    if (!sPres->neighb[side]->neighb[side] && sPres->neighb[side]->nconv[side]==0) { /* One of the ends might be too far from eigenvalues */
-      if (side) *newS = (sPres->value + PetscRealPart(sr->eigr[sr->perm[sr->indexEig-1]]))/2;
-      else *newS = (sPres->value + PetscRealPart(sr->eigr[sr->perm[0]]))/2;
-    } else *newS=(sPres->value + sPres->neighb[side]->value)/2;
+    /* Completing a previous interval */
+    *newS = (sPres->value + sPres->neighb[side]->value)/2;
+    if (PetscAbsReal(sPres->value - *newS)/PetscAbsReal(sPres->value)<=100*PETSC_SQRT_MACHINE_EPSILON) *newS = sPres->value;
   } else { /* (Only for side=1). Creating a new interval. */
     if (sPres->neigs==0) {/* No value has been accepted*/
       if (sPres->neighb[0]) {
