@@ -1,7 +1,7 @@
 /*
    - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
    SLEPc - Scalable Library for Eigenvalue Problem Computations
-   Copyright (c) 2002-2019, Universitat Politecnica de Valencia, Spain
+   Copyright (c) 2002-2020, Universitat Politecnica de Valencia, Spain
 
    This file is part of SLEPc.
    SLEPc is distributed under a 2-clause BSD license (see LICENSE).
@@ -21,7 +21,7 @@
    References:
 
        [1] "Lanczos Methods in SLEPc", SLEPc Technical Report STR-5,
-           available at http://slepc.upv.es.
+           available at https://slepc.upv.es.
 */
 
 #include <slepc/private/epsimpl.h>                /*I "slepceps.h" I*/
@@ -44,7 +44,7 @@ PetscErrorCode EPSSetUp_Lanczos(EPS eps)
   PetscFunctionBegin;
   ierr = EPSSetDimensions_Default(eps,eps->nev,&eps->ncv,&eps->mpd);CHKERRQ(ierr);
   if (eps->ncv>eps->nev+eps->mpd) SETERRQ(PetscObjectComm((PetscObject)eps),1,"The value of ncv must not be larger than nev+mpd");
-  if (!eps->max_it) eps->max_it = PetscMax(100,2*eps->n/eps->ncv);
+  if (eps->max_it==PETSC_DEFAULT) eps->max_it = PetscMax(100,2*eps->n/eps->ncv);
   if (!eps->which) { ierr = EPSSetWhichEigenpairs_Default(eps);CHKERRQ(ierr); }
   switch (eps->which) {
     case EPS_LARGEST_IMAGINARY:
@@ -101,7 +101,7 @@ static PetscErrorCode EPSLocalLanczos(EPS eps,PetscReal *alpha,PetscReal *beta,P
 {
   PetscErrorCode ierr;
   PetscInt       i,j,m = *M;
-  Vec            vj,vj1;
+  Mat            Op;
   PetscBool      *which,lwhich[100];
   PetscScalar    *hwork,lhwork[100];
 
@@ -115,12 +115,9 @@ static PetscErrorCode EPSLocalLanczos(EPS eps,PetscReal *alpha,PetscReal *beta,P
   for (i=0;i<k;i++) which[i] = PETSC_TRUE;
 
   ierr = BVSetActiveColumns(eps->V,0,m);CHKERRQ(ierr);
+  ierr = STGetOperator(eps->st,&Op);CHKERRQ(ierr);
   for (j=k;j<m;j++) {
-    ierr = BVGetColumn(eps->V,j,&vj);CHKERRQ(ierr);
-    ierr = BVGetColumn(eps->V,j+1,&vj1);CHKERRQ(ierr);
-    ierr = STApply(eps->st,vj,vj1);CHKERRQ(ierr);
-    ierr = BVRestoreColumn(eps->V,j,&vj);CHKERRQ(ierr);
-    ierr = BVRestoreColumn(eps->V,j+1,&vj1);CHKERRQ(ierr);
+    ierr = BVMatMultColumn(eps->V,Op,j);CHKERRQ(ierr);
     which[j] = PETSC_TRUE;
     if (j-2>=k) which[j-2] = PETSC_FALSE;
     ierr = BVOrthogonalizeSomeColumn(eps->V,j+1,which,hwork,beta+j,breakdown);CHKERRQ(ierr);
@@ -132,6 +129,7 @@ static PetscErrorCode EPSLocalLanczos(EPS eps,PetscReal *alpha,PetscReal *beta,P
       ierr = BVScaleColumn(eps->V,j+1,1/beta[j]);CHKERRQ(ierr);
     }
   }
+  ierr = STRestoreOperator(eps->st,&Op);CHKERRQ(ierr);
   if (m > 100) {
     ierr = PetscFree2(which,hwork);CHKERRQ(ierr);
   }
@@ -157,10 +155,6 @@ static PetscErrorCode EPSLocalLanczos(EPS eps,PetscReal *alpha,PetscReal *beta,P
 */
 static PetscErrorCode DenseTridiagonal(PetscInt n_,PetscReal *D,PetscReal *E,PetscReal *w,PetscScalar *V)
 {
-#if defined(SLEPC_MISSING_LAPACK_STEVR)
-  PetscFunctionBegin;
-  SETERRQ(PETSC_COMM_SELF,PETSC_ERR_SUP,"STEVR - Lapack routine is unavailable");
-#else
   PetscErrorCode ierr;
   PetscReal      abstol = 0.0,vl,vu,*work;
   PetscBLASInt   il,iu,m,*isuppz,n,lwork,*iwork,liwork,info;
@@ -199,7 +193,6 @@ static PetscErrorCode DenseTridiagonal(PetscInt n_,PetscReal *D,PetscReal *E,Pet
 #endif
   ierr = PetscFree3(isuppz,work,iwork);CHKERRQ(ierr);
   PetscFunctionReturn(0);
-#endif
 }
 
 /*
@@ -210,7 +203,8 @@ static PetscErrorCode EPSSelectiveLanczos(EPS eps,PetscReal *alpha,PetscReal *be
   PetscErrorCode ierr;
   EPS_LANCZOS    *lanczos = (EPS_LANCZOS*)eps->data;
   PetscInt       i,j,m = *M,n,nritz=0,nritzo;
-  Vec            vj,vj1,av;
+  Vec            vj1,av;
+  Mat            Op;
   PetscReal      *d,*e,*ritz,norm;
   PetscScalar    *Y,*hwork;
   PetscBool      *which;
@@ -218,16 +212,13 @@ static PetscErrorCode EPSSelectiveLanczos(EPS eps,PetscReal *alpha,PetscReal *be
   PetscFunctionBegin;
   ierr = PetscCalloc6(m+1,&d,m,&e,m,&ritz,m*m,&Y,m,&which,m,&hwork);CHKERRQ(ierr);
   for (i=0;i<k;i++) which[i] = PETSC_TRUE;
+  ierr = STGetOperator(eps->st,&Op);CHKERRQ(ierr);
 
   for (j=k;j<m;j++) {
     ierr = BVSetActiveColumns(eps->V,0,m);CHKERRQ(ierr);
 
     /* Lanczos step */
-    ierr = BVGetColumn(eps->V,j,&vj);CHKERRQ(ierr);
-    ierr = BVGetColumn(eps->V,j+1,&vj1);CHKERRQ(ierr);
-    ierr = STApply(eps->st,vj,vj1);CHKERRQ(ierr);
-    ierr = BVRestoreColumn(eps->V,j,&vj);CHKERRQ(ierr);
-    ierr = BVRestoreColumn(eps->V,j+1,&vj1);CHKERRQ(ierr);
+    ierr = BVMatMultColumn(eps->V,Op,j);CHKERRQ(ierr);
     which[j] = PETSC_TRUE;
     if (j-2>=k) which[j-2] = PETSC_FALSE;
     ierr = BVOrthogonalizeSomeColumn(eps->V,j+1,which,hwork,&norm,breakdown);CHKERRQ(ierr);
@@ -280,6 +271,7 @@ static PetscErrorCode EPSSelectiveLanczos(EPS eps,PetscReal *alpha,PetscReal *be
     ierr = BVScaleColumn(eps->V,j+1,1.0/norm);CHKERRQ(ierr);
   }
 
+  ierr = STRestoreOperator(eps->st,&Op);CHKERRQ(ierr);
   ierr = PetscFree6(d,e,ritz,Y,which,hwork);CHKERRQ(ierr);
   PetscFunctionReturn(0);
 }
@@ -367,7 +359,7 @@ static PetscErrorCode EPSPartialLanczos(EPS eps,PetscReal *alpha,PetscReal *beta
   PetscErrorCode ierr;
   EPS_LANCZOS    *lanczos = (EPS_LANCZOS*)eps->data;
   PetscInt       i,j,m = *M;
-  Vec            vj,vj1;
+  Mat            Op;
   PetscReal      norm,*omega,lomega[100],*omega_old,lomega_old[100],eps1,delta,eta;
   PetscBool      *which,lwhich[100],*which2,lwhich2[100];
   PetscBool      reorth = PETSC_FALSE,force_reorth = PETSC_FALSE;
@@ -396,12 +388,9 @@ static PetscErrorCode EPSPartialLanczos(EPS eps,PetscReal *alpha,PetscReal *beta
   for (i=0;i<k;i++) which[i] = PETSC_TRUE;
 
   ierr = BVSetActiveColumns(eps->V,0,m);CHKERRQ(ierr);
+  ierr = STGetOperator(eps->st,&Op);CHKERRQ(ierr);
   for (j=k;j<m;j++) {
-    ierr = BVGetColumn(eps->V,j,&vj);CHKERRQ(ierr);
-    ierr = BVGetColumn(eps->V,j+1,&vj1);CHKERRQ(ierr);
-    ierr = STApply(eps->st,vj,vj1);CHKERRQ(ierr);
-    ierr = BVRestoreColumn(eps->V,j,&vj);CHKERRQ(ierr);
-    ierr = BVRestoreColumn(eps->V,j+1,&vj1);CHKERRQ(ierr);
+    ierr = BVMatMultColumn(eps->V,Op,j);CHKERRQ(ierr);
     if (fro) {
       /* Lanczos step with full reorthogonalization */
       ierr = BVOrthogonalizeColumn(eps->V,j+1,hwork,&norm,breakdown);CHKERRQ(ierr);
@@ -463,6 +452,7 @@ static PetscErrorCode EPSPartialLanczos(EPS eps,PetscReal *alpha,PetscReal *beta
     ierr = BVScaleColumn(eps->V,j+1,1.0/norm);CHKERRQ(ierr);
   }
 
+  ierr = STRestoreOperator(eps->st,&Op);CHKERRQ(ierr);
   if (m>100) {
     ierr = PetscFree5(omega,omega_old,which,which2,hwork);CHKERRQ(ierr);
   }
@@ -494,6 +484,7 @@ static PetscErrorCode EPSBasicLanczos(EPS eps,PetscReal *alpha,PetscReal *beta,P
   PetscInt           i,n=*m;
   PetscReal          betam;
   BVOrthogRefineType orthog_ref;
+  Mat                Op;
 
   PetscFunctionBegin;
   switch (lanczos->reorthog) {
@@ -501,7 +492,9 @@ static PetscErrorCode EPSBasicLanczos(EPS eps,PetscReal *alpha,PetscReal *beta,P
       ierr = EPSLocalLanczos(eps,alpha,beta,k,m,breakdown);CHKERRQ(ierr);
       break;
     case EPS_LANCZOS_REORTHOG_FULL:
-      ierr = EPSFullLanczos(eps,alpha,beta,k,m,breakdown);CHKERRQ(ierr);
+      ierr = STGetOperator(eps->st,&Op);CHKERRQ(ierr);
+      ierr = BVMatLanczos(eps->V,Op,alpha,beta,k,m,breakdown);CHKERRQ(ierr);
+      ierr = STRestoreOperator(eps->st,&Op);CHKERRQ(ierr);
       break;
     case EPS_LANCZOS_REORTHOG_SELECTIVE:
       ierr = EPSSelectiveLanczos(eps,alpha,beta,k,m,breakdown,anorm);CHKERRQ(ierr);
