@@ -1,7 +1,7 @@
 /*
    - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
    SLEPc - Scalable Library for Eigenvalue Problem Computations
-   Copyright (c) 2002-2019, Universitat Politecnica de Valencia, Spain
+   Copyright (c) 2002-2020, Universitat Politecnica de Valencia, Spain
 
    This file is part of SLEPc.
    SLEPc is distributed under a 2-clause BSD license (see LICENSE).
@@ -27,7 +27,7 @@
    References:
 
        [1] "Single Vector Iteration Methods in SLEPc", SLEPc Technical Report
-           STR-2, available at http://slepc.upv.es.
+           STR-2, available at https://slepc.upv.es.
 */
 
 #include <slepc/private/epsimpl.h>                /*I "slepceps.h" I*/
@@ -52,7 +52,8 @@ typedef struct {
   void              *formFunctionActx;
   PetscErrorCode    (*formFunctionAB)(SNES,Vec,Vec,Vec,void*);
   PetscInt          idx;  /* index of the first nonzero entry in the iteration vector */
-  PetscInt          p;    /* process id of the owner of idx */
+  PetscMPIInt       p;    /* process id of the owner of idx */
+  PetscReal         norm0; /* norm of initial vector */
 } EPS_POWER;
 
 PetscErrorCode EPSSetUp_Power(EPS eps)
@@ -61,7 +62,7 @@ PetscErrorCode EPSSetUp_Power(EPS eps)
   EPS_POWER      *power = (EPS_POWER*)eps->data;
   PetscBool      flg,istrivial;
   STMatMode      mode;
-  Mat            A,B;
+  Mat            A,B,P;
   Vec            res;
   PetscContainer container;
   PetscErrorCode (*formFunctionA)(SNES,Vec,Vec,void*);
@@ -70,11 +71,11 @@ PetscErrorCode EPSSetUp_Power(EPS eps)
   SNESLineSearch linesearch;
 
   PetscFunctionBegin;
-  if (eps->ncv) {
+  if (eps->ncv!=PETSC_DEFAULT) {
     if (eps->ncv<eps->nev) SETERRQ(PetscObjectComm((PetscObject)eps),1,"The value of ncv must be at least nev");
   } else eps->ncv = eps->nev;
-  if (eps->mpd) { ierr = PetscInfo(eps,"Warning: parameter mpd ignored\n");CHKERRQ(ierr); }
-  if (!eps->max_it) eps->max_it = PetscMax(1000*eps->nev,100*eps->n);
+  if (eps->mpd!=PETSC_DEFAULT) { ierr = PetscInfo(eps,"Warning: parameter mpd ignored\n");CHKERRQ(ierr); }
+  if (eps->max_it==PETSC_DEFAULT) eps->max_it = PetscMax(1000*eps->nev,100*eps->n);
   if (!eps->which) { ierr = EPSSetWhichEigenpairs_Default(eps);CHKERRQ(ierr); }
   if (eps->which!=EPS_LARGEST_MAGNITUDE && eps->which !=EPS_TARGET_MAGNITUDE) SETERRQ(PetscObjectComm((PetscObject)eps),1,"Wrong value of eps->which");
   if (power->shift_type != EPS_POWER_SHIFT_CONSTANT) {
@@ -96,8 +97,17 @@ PetscErrorCode EPSSetUp_Power(EPS eps)
     if (eps->nev>1) SETERRQ(PetscObjectComm((PetscObject)eps),PETSC_ERR_SUP,"Nonlinear inverse iteration cannot compute more than one eigenvalue");
     ierr = EPSSetWorkVecs(eps,4);CHKERRQ(ierr);
 
-    /* set up SNES solver */
-    if (!power->snes) { ierr = EPSPowerGetSNES(eps,&power->snes);CHKERRQ(ierr); }
+    /* Set up SNES solver */
+    /* If SNES was setup, we need to reset it so that it will be consistent with the current EPS */
+    if (power->snes) { ierr = SNESReset(power->snes);CHKERRQ(ierr); }
+    else { ierr = EPSPowerGetSNES(eps,&power->snes);CHKERRQ(ierr); }
+
+    /* For nonlinear solver (Newton), we should scale the initial vector back.
+       The initial vector will be scaled in EPSSetUp. */
+    if (eps->IS) {
+      ierr = VecNorm((eps->IS)[0],NORM_2,&power->norm0);CHKERRQ(ierr);
+    }
+
     ierr = EPSGetOperators(eps,&A,&B);CHKERRQ(ierr);
 
     ierr = PetscObjectQueryFunction((PetscObject)A,"formFunction",&formFunctionA);CHKERRQ(ierr);
@@ -122,7 +132,12 @@ PetscErrorCode EPSSetUp_Power(EPS eps)
     if (container) {
       ierr = PetscContainerGetPointer(container,&ctx);CHKERRQ(ierr);
     } else ctx = NULL;
-    ierr = SNESSetJacobian(power->snes,A,A,formJacobianA,ctx);CHKERRQ(ierr);
+    /* This allows users to compute a different preconditioning matrix than A.
+     * It is useful when A and B are shell matrices.
+     */
+    ierr = STPrecondGetMatForPC(eps->st,&P);CHKERRQ(ierr);
+    /* If users do not provide a matrix, we simply use A */
+    ierr = SNESSetJacobian(power->snes,A,P? P:A,formJacobianA,ctx);CHKERRQ(ierr);
     ierr = SNESSetFromOptions(power->snes);CHKERRQ(ierr);
     ierr = SNESGetLineSearch(power->snes,&linesearch);CHKERRQ(ierr);
     if (power->update) {
@@ -157,7 +172,7 @@ PetscErrorCode EPSSetUp_Power(EPS eps)
 /*
    Find the index of the first nonzero entry of x, and the process that owns it.
 */
-static PetscErrorCode FirstNonzeroIdx(Vec x,PetscInt *idx,PetscInt *p)
+static PetscErrorCode FirstNonzeroIdx(Vec x,PetscInt *idx,PetscMPIInt *p)
 {
   PetscErrorCode    ierr;
   PetscInt          i,first,last,N;
@@ -184,12 +199,11 @@ static PetscErrorCode FirstNonzeroIdx(Vec x,PetscInt *idx,PetscInt *p)
    Normalize a vector x with respect to a given norm as well as the
    sign of the first nonzero entry (assumed to be idx in process p).
 */
-static PetscErrorCode Normalize(Vec x,PetscReal norm,PetscInt idx,PetscInt p,PetscScalar *sign)
+static PetscErrorCode Normalize(Vec x,PetscReal norm,PetscInt idx,PetscMPIInt p,PetscScalar *sign)
 {
   PetscErrorCode    ierr;
   PetscScalar       alpha=1.0;
   PetscInt          first,last;
-  PetscMPIInt       pp;
   PetscReal         absv;
   const PetscScalar *xx;
 
@@ -201,8 +215,7 @@ static PetscErrorCode Normalize(Vec x,PetscReal norm,PetscInt idx,PetscInt p,Pet
     if (absv>10*PETSC_MACHINE_EPSILON) alpha = xx[idx-first]/absv;
     ierr = VecRestoreArrayRead(x,&xx);CHKERRQ(ierr);
   }
-  ierr = PetscMPIIntCast(p,&pp);CHKERRQ(ierr);
-  ierr = MPI_Bcast(&alpha,1,MPIU_SCALAR,pp,PetscObjectComm((PetscObject)x));CHKERRQ(ierr);
+  ierr = MPI_Bcast(&alpha,1,MPIU_SCALAR,p,PetscObjectComm((PetscObject)x));CHKERRQ(ierr);
   if (sign) *sign = alpha;
   alpha *= norm;
   ierr = VecScale(x,1.0/alpha);CHKERRQ(ierr);
@@ -316,7 +329,7 @@ static PetscErrorCode EPSPowerApply_SNES(EPS eps,Vec x,Vec y)
 static PetscErrorCode EPSPowerComputeInitialGuess_Update(EPS eps)
 {
   EPS            powereps;
-  Mat            A,B;
+  Mat            A,B,P;
   Vec            v1,v2;
   SNES           snes;
   DM             dm,newdm;
@@ -333,7 +346,7 @@ static PetscErrorCode EPSPowerComputeInitialGuess_Update(EPS eps)
   ierr = EPSSetProblemType(powereps,EPS_GNHEP);CHKERRQ(ierr);
   ierr = EPSSetWhichEigenpairs(powereps,EPS_TARGET_MAGNITUDE);CHKERRQ(ierr);
   ierr = EPSPowerSetNonlinear(powereps,PETSC_TRUE);CHKERRQ(ierr);
-  ierr = STSetType(powereps->st,STSINVERT);CHKERRQ(ierr);
+  ierr = STPrecondGetMatForPC(eps->st,&P);CHKERRQ(ierr);
   /* attach dm to initial solve */
   ierr = EPSPowerGetSNES(eps,&snes);CHKERRQ(ierr);
   ierr = SNESGetDM(snes,&dm);CHKERRQ(ierr);
@@ -345,6 +358,9 @@ static PetscErrorCode EPSPowerComputeInitialGuess_Update(EPS eps)
   ierr = EPSPowerGetSNES(powereps,&snes);CHKERRQ(ierr);
   ierr = SNESSetDM(snes,dm);CHKERRQ(ierr);
   ierr = EPSSetFromOptions(powereps);CHKERRQ(ierr);
+  if (P) {
+    ierr = STPrecondSetMatForPC(powereps->st,P);CHKERRQ(ierr);
+  }
   ierr = EPSSolve(powereps);CHKERRQ(ierr);
   ierr = BVGetColumn(eps->V,0,&v2);CHKERRQ(ierr);
   ierr = BVGetColumn(powereps->V,0,&v1);CHKERRQ(ierr);
@@ -360,10 +376,6 @@ static PetscErrorCode EPSPowerComputeInitialGuess_Update(EPS eps)
 
 PetscErrorCode EPSSolve_Power(EPS eps)
 {
-#if defined(SLEPC_MISSING_LAPACK_LAEV2)
-  PetscFunctionBegin;
-  SETERRQ(PETSC_COMM_SELF,PETSC_ERR_SUP,"LAEV2 - Lapack routine is unavailable");
-#else
   PetscErrorCode      ierr;
   EPS_POWER           *power = (EPS_POWER*)eps->data;
   PetscInt            k,ld;
@@ -385,7 +397,8 @@ PetscErrorCode EPSSolve_Power(EPS eps)
   if (power->shift_type != EPS_POWER_SHIFT_CONSTANT) { ierr = STGetKSP(eps->st,&ksp);CHKERRQ(ierr); }
   if (power->nonlinear) {
     ierr = PetscObjectCompose((PetscObject)power->snes,"eps",(PetscObject)eps);CHKERRQ(ierr);
-    if (power->update) {
+    /* Compute an intial guess only when users do not provide one */
+    if (power->update && !eps->nini) {
       ierr = EPSPowerComputeInitialGuess_Update(eps);CHKERRQ(ierr);
     }
   } else {
@@ -396,6 +409,10 @@ PetscErrorCode EPSSolve_Power(EPS eps)
   }
   if (power->nonlinear) {
     ierr = BVGetColumn(eps->V,0,&v);CHKERRQ(ierr);
+    if (eps->nini) {
+      /* We scale the initial vector back if the initial vector was provided by users */
+      ierr = VecScale(v,power->norm0);CHKERRQ(ierr);
+    }
     ierr = EPSPowerUpdateFunctionB(eps,v,Bx);CHKERRQ(ierr);
     ierr = VecNorm(Bx,NORM_2,&norm);CHKERRQ(ierr);
     ierr = FirstNonzeroIdx(Bx,&power->idx,&power->p);CHKERRQ(ierr);
@@ -440,7 +457,8 @@ PetscErrorCode EPSSolve_Power(EPS eps)
       ierr = DSRestoreArray(eps->ds,DS_MAT_A,&T);CHKERRQ(ierr);
     }
 
-    if (power->nonlinear) theta = norm*sign;
+    /* Eigenvalue: 1/|Bx| */
+    if (power->nonlinear) theta = 1.0/norm*sign;
 
     if (power->shift_type == EPS_POWER_SHIFT_CONSTANT) { /* direct & inverse iteration */
 
@@ -453,7 +471,10 @@ PetscErrorCode EPSSolve_Power(EPS eps)
       ierr = VecAXPY(e,power->nonlinear?-1.0:-theta,v);CHKERRQ(ierr);
       ierr = BVRestoreColumn(eps->V,k,&v);CHKERRQ(ierr);
       ierr = VecNorm(e,NORM_2,&relerr);CHKERRQ(ierr);
-      relerr /= PetscAbsScalar(theta);
+      if (power->nonlinear)
+        relerr *= PetscAbsScalar(theta);
+      else
+        relerr /= PetscAbsScalar(theta);
 
     } else {  /* RQI */
 
@@ -543,7 +564,6 @@ PetscErrorCode EPSSolve_Power(EPS eps)
     ierr = DSSetState(eps->ds,DS_STATE_RAW);CHKERRQ(ierr);
   }
   PetscFunctionReturn(0);
-#endif
 }
 
 PetscErrorCode EPSSolve_TS_Power(EPS eps)
@@ -555,7 +575,7 @@ PetscErrorCode EPSSolve_TS_Power(EPS eps)
   KSP                ksp;
   PetscReal          relerr=1.0,relerrl,delta;
   PetscScalar        theta,rho,alpha,sigma;
-  PetscBool          breakdown;
+  PetscBool          breakdown,breakdownl;
   KSPConvergedReason reason;
 
   PetscFunctionBegin;
@@ -566,7 +586,7 @@ PetscErrorCode EPSSolve_TS_Power(EPS eps)
   if (power->shift_type != EPS_POWER_SHIFT_CONSTANT) { ierr = STGetKSP(eps->st,&ksp);CHKERRQ(ierr); }
   ierr = DSGetLeadingDimension(eps->ds,&ld);CHKERRQ(ierr);
   ierr = EPSGetStartVector(eps,0,NULL);CHKERRQ(ierr);
-  ierr = BVSetRandomColumn(eps->W,0);CHKERRQ(ierr);
+  ierr = EPSGetLeftStartVector(eps,0,NULL);CHKERRQ(ierr);
   ierr = BVBiorthonormalizeColumn(eps->V,eps->W,0,NULL);CHKERRQ(ierr);
   ierr = BVCopyVec(eps->V,0,v);CHKERRQ(ierr);
   ierr = BVCopyVec(eps->W,0,w);CHKERRQ(ierr);
@@ -582,10 +602,7 @@ PetscErrorCode EPSSolve_TS_Power(EPS eps)
     ierr = STApply(eps->st,v,y);CHKERRQ(ierr);
     ierr = BVRestoreColumn(eps->V,k,&y);CHKERRQ(ierr);
     ierr = BVGetColumn(eps->W,k,&z);CHKERRQ(ierr);
-    ierr = VecConjugate(w);CHKERRQ(ierr);
-    ierr = STApplyTranspose(eps->st,w,z);CHKERRQ(ierr);
-    ierr = VecConjugate(w);CHKERRQ(ierr);
-    ierr = VecConjugate(z);CHKERRQ(ierr);
+    ierr = STApplyHermitianTranspose(eps->st,w,z);CHKERRQ(ierr);
     ierr = BVRestoreColumn(eps->W,k,&z);CHKERRQ(ierr);
 
     /* purge previously converged eigenvectors */
@@ -659,12 +676,12 @@ PetscErrorCode EPSSolve_TS_Power(EPS eps)
       eps->nconv = eps->nconv + 1;
       if (eps->nconv<eps->nev) {
         ierr = EPSGetStartVector(eps,eps->nconv,&breakdown);CHKERRQ(ierr);
-        if (breakdown) {
+        ierr = EPSGetLeftStartVector(eps,eps->nconv,&breakdownl);CHKERRQ(ierr);
+        if (breakdown || breakdownl) {
           eps->reason = EPS_DIVERGED_BREAKDOWN;
           ierr = PetscInfo(eps,"Unable to generate more start vectors\n");CHKERRQ(ierr);
           break;
         }
-        ierr = BVSetRandomColumn(eps->W,eps->nconv);CHKERRQ(ierr);
         ierr = BVBiorthonormalizeColumn(eps->V,eps->W,eps->nconv,NULL);CHKERRQ(ierr);
       }
     }
@@ -1163,7 +1180,12 @@ PetscErrorCode EPSSetDefaultST_Power(EPS eps)
 
   PetscFunctionBegin;
   if (power->nonlinear) {
+    eps->categ=EPS_CATEGORY_PRECOND;
     ierr = STGetKSP(eps->st,&ksp);CHKERRQ(ierr);
+    /* Set ST as STPRECOND so it can carry one preconditioning matrix
+     * It is useful when A and B are shell matrices
+     */
+    ierr = STSetType(eps->st,STPRECOND);CHKERRQ(ierr);
     ierr = KSPGetPC(ksp,&pc);CHKERRQ(ierr);
     ierr = PCSetType(pc,PCNONE);CHKERRQ(ierr);
   }
@@ -1203,4 +1225,3 @@ SLEPC_EXTERN PetscErrorCode EPSCreate_Power(EPS eps)
   ierr = PetscObjectComposeFunction((PetscObject)eps,"EPSPowerGetSNES_C",EPSPowerGetSNES_Power);CHKERRQ(ierr);
   PetscFunctionReturn(0);
 }
-
