@@ -1,7 +1,7 @@
 /*
    - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
    SLEPc - Scalable Library for Eigenvalue Problem Computations
-   Copyright (c) 2002-2019, Universitat Politecnica de Valencia, Spain
+   Copyright (c) 2002-2020, Universitat Politecnica de Valencia, Spain
 
    This file is part of SLEPc.
    SLEPc is distributed under a 2-clause BSD license (see LICENSE).
@@ -39,7 +39,7 @@
 
    Level: beginner
 
-.seealso: STView(), PetscViewerASCIIOpen()
+.seealso: STView()
 @*/
 PetscErrorCode EPSView(EPS eps,PetscViewer viewer)
 {
@@ -194,6 +194,9 @@ PetscErrorCode EPSView(EPS eps,PetscViewer viewer)
     if (eps->nini) {
       ierr = PetscViewerASCIIPrintf(viewer,"  dimension of user-provided initial space: %D\n",PetscAbs(eps->nini));CHKERRQ(ierr);
     }
+    if (eps->ninil) {
+      ierr = PetscViewerASCIIPrintf(viewer,"  dimension of user-provided left initial space: %D\n",PetscAbs(eps->ninil));CHKERRQ(ierr);
+    }
     if (eps->nds) {
       ierr = PetscViewerASCIIPrintf(viewer,"  dimension of user-provided deflation space: %D\n",PetscAbs(eps->nds));CHKERRQ(ierr);
     }
@@ -222,12 +225,36 @@ PetscErrorCode EPSView(EPS eps,PetscViewer viewer)
   PetscFunctionReturn(0);
 }
 
+/*@C
+   EPSViewFromOptions - View from options
+
+   Collective on EPS
+
+   Input Parameters:
++  eps  - the eigensolver context
+.  obj  - optional object
+-  name - command line option
+
+   Level: intermediate
+
+.seealso: EPSView(), EPSCreate()
+@*/
+PetscErrorCode EPSViewFromOptions(EPS eps,PetscObject obj,const char name[])
+{
+  PetscErrorCode ierr;
+
+  PetscFunctionBegin;
+  PetscValidHeaderSpecific(eps,EPS_CLASSID,1);
+  ierr = PetscObjectViewFromOptions((PetscObject)eps,obj,name);CHKERRQ(ierr);
+  PetscFunctionReturn(0);
+}
+
 /*@C
    EPSReasonView - Displays the reason an EPS solve converged or diverged.
 
    Collective on eps
 
-   Parameter:
+   Input Parameters:
 +  eps - the eigensolver context
 -  viewer - the viewer to display the reason
 
@@ -263,7 +290,7 @@ PetscErrorCode EPSReasonView(EPS eps,PetscViewer viewer)
 
    Collective on eps
 
-   Input Parameters:
+   Input Parameter:
 .  eps - the eigensolver context
 
    Level: developer
@@ -458,7 +485,7 @@ PetscErrorCode EPSErrorView(EPS eps,EPSErrorType etype,PetscViewer viewer)
 
    Collective on eps
 
-   Input Parameters:
+   Input Parameter:
 .  eps - the eigensolver context
 
    Level: developer
@@ -730,7 +757,7 @@ PetscErrorCode EPSVectorsView(EPS eps,PetscViewer viewer)
 
    Collective on eps
 
-   Input Parameters:
+   Input Parameter:
 .  eps - the eigensolver context
 
    Level: developer
