@@ -1,7 +1,7 @@
 /*
    - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
    SLEPc - Scalable Library for Eigenvalue Problem Computations
-   Copyright (c) 2002-2019, Universitat Politecnica de Valencia, Spain
+   Copyright (c) 2002-2020, Universitat Politecnica de Valencia, Spain
 
    This file is part of SLEPc.
    SLEPc is distributed under a 2-clause BSD license (see LICENSE).
@@ -314,10 +314,6 @@ static PetscErrorCode BlockHankel(NEP nep,PetscScalar *Mu,PetscInt s,PetscScalar
 
 static PetscErrorCode SVD_H0(NEP nep,PetscScalar *S,PetscInt *K)
 {
-#if defined(PETSC_MISSING_LAPACK_GESVD)
-  PetscFunctionBegin;
-  SETERRQ(PETSC_COMM_SELF,PETSC_ERR_SUP,"GESVD - Lapack routine is unavailable");
-#else
   PetscErrorCode ierr;
   NEP_CISS       *ctx = (NEP_CISS*)nep->data;
   PetscInt       i,ml=ctx->L*ctx->M;
@@ -351,7 +347,6 @@ static PetscErrorCode SVD_H0(NEP nep,PetscScalar *S,PetscInt *K)
   ierr = PetscFree(rwork);CHKERRQ(ierr);
 #endif
   PetscFunctionReturn(0);
-#endif
 }
 
 static PetscErrorCode ConstructS(NEP nep)
@@ -439,7 +434,7 @@ PetscErrorCode NEPSetUp_CISS(NEP nep)
   PetscBool      istrivial,isellipse,flg,useconj;
 
   PetscFunctionBegin;
-  if (!nep->ncv) {
+  if (nep->ncv==PETSC_DEFAULT) {
     nep->ncv = ctx->L_max*ctx->M;
     if (nep->ncv>nep->n) {
       nep->ncv = nep->n;
@@ -454,8 +449,8 @@ PetscErrorCode NEPSetUp_CISS(NEP nep)
     }
   }
   ctx->L = PetscMin(ctx->L,ctx->L_max);
-  if (!nep->max_it) nep->max_it = 1;
-  if (!nep->mpd) nep->mpd = nep->ncv;
+  if (nep->max_it==PETSC_DEFAULT) nep->max_it = 1;
+  if (nep->mpd==PETSC_DEFAULT) nep->mpd = nep->ncv;
   if (!nep->which) nep->which = NEP_ALL;
   if (nep->stopping!=NEPStoppingBasic) SETERRQ(PetscObjectComm((PetscObject)nep),PETSC_ERR_SUP,"This solver does not support user-defined stopping test");
 
@@ -562,7 +557,7 @@ PetscErrorCode NEPSolve_CISS(NEP nep)
     }
 
     nep->nconv = 0;
-    if (nv == 0) break;
+    if (nv == 0) { nep->reason = NEP_CONVERGED_TOL; break; }
     ierr = BlockHankel(nep,Mu,0,H0);CHKERRQ(ierr);
     ierr = BlockHankel(nep,Mu,1,H1);CHKERRQ(ierr);
     ierr = DSSetDimensions(nep->ds,nv,0,0,0);CHKERRQ(ierr);
