@@ -1,7 +1,7 @@
 /*
    - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
    SLEPc - Scalable Library for Eigenvalue Problem Computations
-   Copyright (c) 2002-2019, Universitat Politecnica de Valencia, Spain
+   Copyright (c) 2002-2020, Universitat Politecnica de Valencia, Spain
 
    This file is part of SLEPc.
    SLEPc is distributed under a 2-clause BSD license (see LICENSE).
@@ -29,6 +29,8 @@ typedef struct {
   PetscInt  max_inner_it;     /* maximum number of Newton iterations */
   PetscInt  lag;              /* interval to rebuild preconditioner */
   PetscBool cctol;            /* constant correction tolerance */
+  PetscBool herm;             /* whether the Hermitian version of the scalar equation must be used */
+  PetscReal deftol;           /* tolerance for the deflation (threshold) */
   KSP       ksp;              /* linear solver object */
 } NEP_RII;
 
@@ -38,11 +40,11 @@ PetscErrorCode NEPSetUp_RII(NEP nep)
   PetscBool      istrivial;
 
   PetscFunctionBegin;
-  if (nep->ncv) { ierr = PetscInfo(nep,"Setting ncv = nev, ignoring user-provided value\n");CHKERRQ(ierr); }
+  if (nep->ncv!=PETSC_DEFAULT) { ierr = PetscInfo(nep,"Setting ncv = nev, ignoring user-provided value\n");CHKERRQ(ierr); }
   nep->ncv = nep->nev;
-  if (nep->mpd) { ierr = PetscInfo(nep,"Setting mpd = nev, ignoring user-provided value\n");CHKERRQ(ierr); }
+  if (nep->mpd!=PETSC_DEFAULT) { ierr = PetscInfo(nep,"Setting mpd = nev, ignoring user-provided value\n");CHKERRQ(ierr); }
   nep->mpd = nep->nev;
-  if (!nep->max_it) nep->max_it = PetscMax(5000,2*nep->n/nep->ncv);
+  if (nep->max_it==PETSC_DEFAULT) nep->max_it = PetscMax(5000,2*nep->n/nep->ncv);
   if (nep->which && nep->which!=NEP_TARGET_MAGNITUDE) SETERRQ(PetscObjectComm((PetscObject)nep),1,"Wrong value of which");
 
   ierr = RGIsTrivial(nep->rg,&istrivial);CHKERRQ(ierr);
@@ -58,10 +60,10 @@ PetscErrorCode NEPSolve_RII(NEP nep)
   PetscErrorCode     ierr;
   NEP_RII            *ctx = (NEP_RII*)nep->data;
   Mat                T,Tp,H;
-  Vec                uu,u,r,delta;
+  Vec                uu,u,r,delta,t;
   PetscScalar        lambda,lambda2,sigma,a1,a2,corr,*Hp,*Ap;
-  PetscReal          nrm,resnorm=1.0,ktol=0.1,perr;
-  PetscBool          skip=PETSC_FALSE;
+  PetscReal          nrm,resnorm=1.0,ktol=0.1,perr,rtol;
+  PetscBool          skip=PETSC_FALSE,lock=PETSC_FALSE;
   PetscInt           inner_its,its=0,ldh,ldds,i,j;
   NEP_EXT_OP         extop=NULL;
   KSPConvergedReason kspreason;
@@ -86,6 +88,7 @@ PetscErrorCode NEPSolve_RII(NEP nep)
 
   /* prepare linear solver */
   ierr = NEPDeflationSolveSetUp(extop,sigma);CHKERRQ(ierr);
+  ierr = KSPGetTolerances(ctx->ksp,&rtol,NULL,NULL,NULL);CHKERRQ(ierr);
 
   ierr = VecCopy(u,r);CHKERRQ(ierr);
   ierr = NEPDeflationFunctionSolve(extop,r,u);CHKERRQ(ierr);
@@ -103,11 +106,26 @@ PetscErrorCode NEPSolve_RII(NEP nep)
     do {
       ierr = NEPDeflationComputeFunction(extop,lambda,&T);CHKERRQ(ierr);
       ierr = MatMult(T,u,r);CHKERRQ(ierr);
-      ierr = VecDot(r,u,&a1);CHKERRQ(ierr);
-      if (inner_its && PetscAbsScalar(a1)/PetscAbsScalar(lambda)<=PETSC_SQRT_MACHINE_EPSILON) break;
+      if (!ctx->herm) {
+        ierr = NEPDeflationFunctionSolve(extop,r,delta);CHKERRQ(ierr);
+        ierr = KSPGetConvergedReason(ctx->ksp,&kspreason);CHKERRQ(ierr);
+        if (kspreason<0) {
+          ierr = PetscInfo1(nep,"iter=%D, linear solve failed\n",nep->its);CHKERRQ(ierr);
+        }
+        t = delta;
+      } else t = r;
+      ierr = VecDot(t,u,&a1);CHKERRQ(ierr);
       ierr = NEPDeflationComputeJacobian(extop,lambda,&Tp);CHKERRQ(ierr);
       ierr = MatMult(Tp,u,r);CHKERRQ(ierr);
-      ierr = VecDot(r,u,&a2);CHKERRQ(ierr);
+      if (!ctx->herm) {
+        ierr = NEPDeflationFunctionSolve(extop,r,delta);CHKERRQ(ierr);
+        ierr = KSPGetConvergedReason(ctx->ksp,&kspreason);CHKERRQ(ierr);
+        if (kspreason<0) {
+          ierr = PetscInfo1(nep,"iter=%D, linear solve failed\n",nep->its);CHKERRQ(ierr);
+        }
+        t = delta;
+      } else t = r;
+      ierr = VecDot(t,u,&a2);CHKERRQ(ierr);
       corr = a1/a2;
       lambda = lambda - corr;
       inner_its++;
@@ -122,11 +140,23 @@ PetscErrorCode NEPSolve_RII(NEP nep)
     ierr = VecNorm(r,NORM_2,&resnorm);CHKERRQ(ierr);
     ierr = (*nep->converged)(nep,lambda,0,resnorm,&nep->errest[nep->nconv],nep->convergedctx);CHKERRQ(ierr);
     nep->eigr[nep->nconv] = lambda;
-    if (nep->errest[nep->nconv]<=nep->tol) {
+    if (its>1 && (nep->errest[nep->nconv]<=nep->tol || nep->errest[nep->nconv]<=ctx->deftol)) {
+      if (nep->errest[nep->nconv]<=ctx->deftol && !extop->ref && nep->nconv) {
+        ierr = NEPDeflationExtractEigenpair(extop,nep->nconv,u,lambda,nep->ds);CHKERRQ(ierr);
+        ierr = NEPDeflationSetRefine(extop,PETSC_TRUE);CHKERRQ(ierr);
+        ierr = MatMult(T,u,r);CHKERRQ(ierr);
+        ierr = VecNorm(r,NORM_2,&resnorm);CHKERRQ(ierr);
+        ierr = (*nep->converged)(nep,lambda,0,resnorm,&nep->errest[nep->nconv],nep->convergedctx);CHKERRQ(ierr);
+        if (nep->errest[nep->nconv]<=nep->tol) lock = PETSC_TRUE;
+      } else if (nep->errest[nep->nconv]<=nep->tol) lock = PETSC_TRUE;
+    }
+    if (lock) {
+      ierr = NEPDeflationSetRefine(extop,PETSC_FALSE);CHKERRQ(ierr);
       nep->nconv = nep->nconv + 1;
       ierr = NEPDeflationLocking(extop,u,lambda);CHKERRQ(ierr);
       nep->its += its;
       skip = PETSC_TRUE;
+      lock = PETSC_FALSE;
     }
     ierr = (*nep->stopping)(nep,nep->its+its,nep->max_it,nep->nconv,nep->nev,&nep->reason,nep->stoppingctx);CHKERRQ(ierr);
     if (!skip || nep->reason>0) {
@@ -140,7 +170,7 @@ PetscErrorCode NEPSolve_RII(NEP nep)
           ierr = NEPDeflationSolveSetUp(extop,lambda2);CHKERRQ(ierr);
         }
         if (!ctx->cctol) {
-          ktol = PetscMax(ktol/2.0,PETSC_MACHINE_EPSILON*10.0);
+          ktol = PetscMax(ktol/2.0,rtol);
           ierr = KSPSetTolerances(ctx->ksp,ktol,PETSC_DEFAULT,PETSC_DEFAULT,PETSC_DEFAULT);CHKERRQ(ierr);
         }
 
@@ -174,6 +204,7 @@ PetscErrorCode NEPSolve_RII(NEP nep)
   ierr = NEPDeflationGetInvariantPair(extop,NULL,&H);CHKERRQ(ierr);
   ierr = MatGetSize(H,NULL,&ldh);CHKERRQ(ierr);
   ierr = DSSetType(nep->ds,DSNHEP);CHKERRQ(ierr);
+  ierr = DSReset(nep->ds);CHKERRQ(ierr);
   ierr = DSAllocate(nep->ds,PetscMax(nep->nconv,1));CHKERRQ(ierr);
   ierr = DSGetLeadingDimension(nep->ds,&ldds);CHKERRQ(ierr);
   ierr = MatDenseGetArray(H,&Hp);CHKERRQ(ierr);
@@ -198,6 +229,7 @@ PetscErrorCode NEPSetFromOptions_RII(PetscOptionItems *PetscOptionsObject,NEP ne
   NEP_RII        *ctx = (NEP_RII*)nep->data;
   PetscBool      flg;
   PetscInt       i;
+  PetscReal      r;
 
   PetscFunctionBegin;
   ierr = PetscOptionsHead(PetscOptionsObject,"NEP RII Options");CHKERRQ(ierr);
@@ -208,10 +240,16 @@ PetscErrorCode NEPSetFromOptions_RII(PetscOptionItems *PetscOptionsObject,NEP ne
 
     ierr = PetscOptionsBool("-nep_rii_const_correction_tol","Constant correction tolerance for the linear solver","NEPRIISetConstCorrectionTol",ctx->cctol,&ctx->cctol,NULL);CHKERRQ(ierr);
 
+    ierr = PetscOptionsBool("-nep_rii_hermitian","Use Hermitian version of the scalar nonlinear equation","NEPRIISetHermitian",ctx->herm,&ctx->herm,NULL);CHKERRQ(ierr);
+
     i = 0;
     ierr = PetscOptionsInt("-nep_rii_lag_preconditioner","Interval to rebuild preconditioner","NEPRIISetLagPreconditioner",ctx->lag,&i,&flg);CHKERRQ(ierr);
     if (flg) { ierr = NEPRIISetLagPreconditioner(nep,i);CHKERRQ(ierr); }
 
+    r = 0.0;
+    ierr = PetscOptionsReal("-nep_rii_deflation_threshold","Tolerance used as a threshold for including deflated eigenpairs","NEPRIISetDeflationThreshold",ctx->deftol,&r,&flg);CHKERRQ(ierr);
+    if (flg) { ierr = NEPRIISetDeflationThreshold(nep,r);CHKERRQ(ierr); }
+
   ierr = PetscOptionsTail();CHKERRQ(ierr);
 
   if (!ctx->ksp) { ierr = NEPRIIGetKSP(nep,&ctx->ksp);CHKERRQ(ierr); }
@@ -410,7 +448,7 @@ PetscErrorCode NEPRIISetConstCorrectionTol(NEP nep,PetscBool cct)
 
   PetscFunctionBegin;
   PetscValidHeaderSpecific(nep,NEP_CLASSID,1);
-  PetscValidLogicalCollectiveInt(nep,cct,2);
+  PetscValidLogicalCollectiveBool(nep,cct,2);
   ierr = PetscTryMethod(nep,"NEPRIISetConstCorrectionTol_C",(NEP,PetscBool),(nep,cct));CHKERRQ(ierr);
   PetscFunctionReturn(0);
 }
@@ -450,6 +488,165 @@ PetscErrorCode NEPRIIGetConstCorrectionTol(NEP nep,PetscBool *cct)
   PetscFunctionReturn(0);
 }
 
+static PetscErrorCode NEPRIISetHermitian_RII(NEP nep,PetscBool herm)
+{
+  NEP_RII *ctx = (NEP_RII*)nep->data;
+
+  PetscFunctionBegin;
+  ctx->herm = herm;
+  PetscFunctionReturn(0);
+}
+
+/*@
+   NEPRIISetHermitian - Sets a flag to indicate if the Hermitian version of the
+   scalar nonlinear equation must be used by the solver.
+
+   Logically Collective on nep
+
+   Input Parameters:
++  nep  - nonlinear eigenvalue solver
+-  herm - a boolean value
+
+   Options Database Keys:
+.  -nep_rii_hermitian <bool> - set the boolean flag
+
+   Notes:
+   By default, the scalar nonlinear equation x'*inv(T(sigma))*T(z)*x=0 is solved
+   at each step of the nonlinear iteration. When this flag is set the simpler
+   form x'*T(z)*x=0 is used, which is supposed to be valid only for Hermitian
+   problems.
+
+   Level: intermediate
+
+.seealso: NEPRIIGetHermitian()
+@*/
+PetscErrorCode NEPRIISetHermitian(NEP nep,PetscBool herm)
+{
+  PetscErrorCode ierr;
+
+  PetscFunctionBegin;
+  PetscValidHeaderSpecific(nep,NEP_CLASSID,1);
+  PetscValidLogicalCollectiveBool(nep,herm,2);
+  ierr = PetscTryMethod(nep,"NEPRIISetHermitian_C",(NEP,PetscBool),(nep,herm));CHKERRQ(ierr);
+  PetscFunctionReturn(0);
+}
+
+static PetscErrorCode NEPRIIGetHermitian_RII(NEP nep,PetscBool *herm)
+{
+  NEP_RII *ctx = (NEP_RII*)nep->data;
+
+  PetscFunctionBegin;
+  *herm = ctx->herm;
+  PetscFunctionReturn(0);
+}
+
+/*@
+   NEPRIIGetHermitian - Returns the flag about using the Hermitian version of
+   the scalar nonlinear equation.
+
+   Not Collective
+
+   Input Parameter:
+.  nep - nonlinear eigenvalue solver
+
+   Output Parameter:
+.  herm - the value of the hermitian flag
+
+   Level: intermediate
+
+.seealso: NEPRIISetHermitian()
+@*/
+PetscErrorCode NEPRIIGetHermitian(NEP nep,PetscBool *herm)
+{
+  PetscErrorCode ierr;
+
+  PetscFunctionBegin;
+  PetscValidHeaderSpecific(nep,NEP_CLASSID,1);
+  PetscValidBoolPointer(herm,2);
+  ierr = PetscUseMethod(nep,"NEPRIIGetHermitian_C",(NEP,PetscBool*),(nep,herm));CHKERRQ(ierr);
+  PetscFunctionReturn(0);
+}
+
+static PetscErrorCode NEPRIISetDeflationThreshold_RII(NEP nep,PetscReal deftol)
+{
+  NEP_RII *ctx = (NEP_RII*)nep->data;
+
+  PetscFunctionBegin;
+  ctx->deftol = deftol;
+  PetscFunctionReturn(0);
+}
+
+/*@
+   NEPRIISetDeflationThreshold - Sets the threshold value used to switch between
+   deflated and non-deflated iteration.
+
+   Logically Collective on nep
+
+   Input Parameters:
++  nep    - nonlinear eigenvalue solver
+-  deftol - the threshold value
+
+   Options Database Keys:
+.  -nep_rii_deflation_threshold <deftol> - set the threshold
+
+   Notes:
+   Normally, the solver iterates on the extended problem in order to deflate
+   previously converged eigenpairs. If this threshold is set to a nonzero value,
+   then once the residual error is below this threshold the solver will
+   continue the iteration without deflation. The intention is to be able to
+   improve the current eigenpair further, despite having previous eigenpairs
+   with somewhat bad precision.
+
+   Level: advanced
+
+.seealso: NEPRIIGetDeflationThreshold()
+@*/
+PetscErrorCode NEPRIISetDeflationThreshold(NEP nep,PetscReal deftol)
+{
+  PetscErrorCode ierr;
+
+  PetscFunctionBegin;
+  PetscValidHeaderSpecific(nep,NEP_CLASSID,1);
+  PetscValidLogicalCollectiveReal(nep,deftol,2);
+  ierr = PetscTryMethod(nep,"NEPRIISetDeflationThreshold_C",(NEP,PetscReal),(nep,deftol));CHKERRQ(ierr);
+  PetscFunctionReturn(0);
+}
+
+static PetscErrorCode NEPRIIGetDeflationThreshold_RII(NEP nep,PetscReal *deftol)
+{
+  NEP_RII *ctx = (NEP_RII*)nep->data;
+
+  PetscFunctionBegin;
+  *deftol = ctx->deftol;
+  PetscFunctionReturn(0);
+}
+
+/*@
+   NEPRIIGetDeflationThreshold - Returns the threshold value that controls deflation.
+
+   Not Collective
+
+   Input Parameter:
+.  nep - nonlinear eigenvalue solver
+
+   Output Parameter:
+.  deftol - the threshold
+
+   Level: advanced
+
+.seealso: NEPRIISetDeflationThreshold()
+@*/
+PetscErrorCode NEPRIIGetDeflationThreshold(NEP nep,PetscReal *deftol)
+{
+  PetscErrorCode ierr;
+
+  PetscFunctionBegin;
+  PetscValidHeaderSpecific(nep,NEP_CLASSID,1);
+  PetscValidBoolPointer(deftol,2);
+  ierr = PetscUseMethod(nep,"NEPRIIGetDeflationThreshold_C",(NEP,PetscReal*),(nep,deftol));CHKERRQ(ierr);
+  PetscFunctionReturn(0);
+}
+
 static PetscErrorCode NEPRIISetKSP_RII(NEP nep,KSP ksp)
 {
   PetscErrorCode ierr;
@@ -550,9 +747,15 @@ PetscErrorCode NEPView_RII(NEP nep,PetscViewer viewer)
     if (ctx->cctol) {
       ierr = PetscViewerASCIIPrintf(viewer,"  using a constant tolerance for the linear solver\n");CHKERRQ(ierr);
     }
+    if (ctx->herm) {
+      ierr = PetscViewerASCIIPrintf(viewer,"  using the Hermitian version of the scalar nonlinear equation\n");CHKERRQ(ierr);
+    }
     if (ctx->lag) {
       ierr = PetscViewerASCIIPrintf(viewer,"  updating the preconditioner every %D iterations\n",ctx->lag);CHKERRQ(ierr);
     }
+    if (ctx->deftol) {
+      ierr = PetscViewerASCIIPrintf(viewer,"  deflation threshold: %g\n",(double)ctx->deftol);CHKERRQ(ierr);
+    }
     if (!ctx->ksp) { ierr = NEPRIIGetKSP(nep,&ctx->ksp);CHKERRQ(ierr); }
     ierr = PetscViewerASCIIPushTab(viewer);CHKERRQ(ierr);
     ierr = KSPView(ctx->ksp,viewer);CHKERRQ(ierr);
@@ -585,6 +788,10 @@ PetscErrorCode NEPDestroy_RII(NEP nep)
   ierr = PetscObjectComposeFunction((PetscObject)nep,"NEPRIIGetLagPreconditioner_C",NULL);CHKERRQ(ierr);
   ierr = PetscObjectComposeFunction((PetscObject)nep,"NEPRIISetConstCorrectionTol_C",NULL);CHKERRQ(ierr);
   ierr = PetscObjectComposeFunction((PetscObject)nep,"NEPRIIGetConstCorrectionTol_C",NULL);CHKERRQ(ierr);
+  ierr = PetscObjectComposeFunction((PetscObject)nep,"NEPRIISetHermitian_C",NULL);CHKERRQ(ierr);
+  ierr = PetscObjectComposeFunction((PetscObject)nep,"NEPRIIGetHermitian_C",NULL);CHKERRQ(ierr);
+  ierr = PetscObjectComposeFunction((PetscObject)nep,"NEPRIISetDeflationThreshold_C",NULL);CHKERRQ(ierr);
+  ierr = PetscObjectComposeFunction((PetscObject)nep,"NEPRIIGetDeflationThreshold_C",NULL);CHKERRQ(ierr);
   ierr = PetscObjectComposeFunction((PetscObject)nep,"NEPRIISetKSP_C",NULL);CHKERRQ(ierr);
   ierr = PetscObjectComposeFunction((PetscObject)nep,"NEPRIIGetKSP_C",NULL);CHKERRQ(ierr);
   PetscFunctionReturn(0);
@@ -601,6 +808,8 @@ SLEPC_EXTERN PetscErrorCode NEPCreate_RII(NEP nep)
   ctx->max_inner_it = 10;
   ctx->lag          = 1;
   ctx->cctol        = PETSC_FALSE;
+  ctx->herm         = PETSC_FALSE;
+  ctx->deftol       = 0.0;
 
   nep->useds = PETSC_TRUE;
 
@@ -618,6 +827,10 @@ SLEPC_EXTERN PetscErrorCode NEPCreate_RII(NEP nep)
   ierr = PetscObjectComposeFunction((PetscObject)nep,"NEPRIIGetLagPreconditioner_C",NEPRIIGetLagPreconditioner_RII);CHKERRQ(ierr);
   ierr = PetscObjectComposeFunction((PetscObject)nep,"NEPRIISetConstCorrectionTol_C",NEPRIISetConstCorrectionTol_RII);CHKERRQ(ierr);
   ierr = PetscObjectComposeFunction((PetscObject)nep,"NEPRIIGetConstCorrectionTol_C",NEPRIIGetConstCorrectionTol_RII);CHKERRQ(ierr);
+  ierr = PetscObjectComposeFunction((PetscObject)nep,"NEPRIISetHermitian_C",NEPRIISetHermitian_RII);CHKERRQ(ierr);
+  ierr = PetscObjectComposeFunction((PetscObject)nep,"NEPRIIGetHermitian_C",NEPRIIGetHermitian_RII);CHKERRQ(ierr);
+  ierr = PetscObjectComposeFunction((PetscObject)nep,"NEPRIISetDeflationThreshold_C",NEPRIISetDeflationThreshold_RII);CHKERRQ(ierr);
+  ierr = PetscObjectComposeFunction((PetscObject)nep,"NEPRIIGetDeflationThreshold_C",NEPRIIGetDeflationThreshold_RII);CHKERRQ(ierr);
   ierr = PetscObjectComposeFunction((PetscObject)nep,"NEPRIISetKSP_C",NEPRIISetKSP_RII);CHKERRQ(ierr);
   ierr = PetscObjectComposeFunction((PetscObject)nep,"NEPRIIGetKSP_C",NEPRIIGetKSP_RII);CHKERRQ(ierr);
   PetscFunctionReturn(0);
