@@ -1,7 +1,7 @@
 /*
    - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
    SLEPc - Scalable Library for Eigenvalue Problem Computations
-   Copyright (c) 2002-2019, Universitat Politecnica de Valencia, Spain
+   Copyright (c) 2002-2020, Universitat Politecnica de Valencia, Spain
 
    This file is part of SLEPc.
    SLEPc is distributed under a 2-clause BSD license (see LICENSE).
@@ -24,16 +24,12 @@
 
 #include <slepc/private/nepimpl.h>         /*I "slepcnep.h" I*/
 #include <../src/nep/impls/nepdefl.h>
-
-typedef struct {
-  EPS        eps;      /* linear eigensolver for T*z = mu*Tp*z */
-  KSP        ksp;
-} NEP_SLP;
+#include "slp.h"
 
 typedef struct {
   NEP_EXT_OP extop;
   Vec        w;
-} NEP_SLP_EPS_MSHELL;
+} NEP_SLP_MATSHELL;
 
 PetscErrorCode NEPSetUp_SLP(NEP nep)
 {
@@ -43,12 +39,12 @@ PetscErrorCode NEPSetUp_SLP(NEP nep)
   ST             st;
 
   PetscFunctionBegin;
-  if (nep->ncv) { ierr = PetscInfo(nep,"Setting ncv = nev, ignoring user-provided value\n");CHKERRQ(ierr); }
+  if (nep->ncv!=PETSC_DEFAULT) { ierr = PetscInfo(nep,"Setting ncv = nev, ignoring user-provided value\n");CHKERRQ(ierr); }
   nep->ncv = nep->nev;
-  if (nep->mpd) { ierr = PetscInfo(nep,"Setting mpd = nev, ignoring user-provided value\n");CHKERRQ(ierr); }
+  if (nep->mpd!=PETSC_DEFAULT) { ierr = PetscInfo(nep,"Setting mpd = nev, ignoring user-provided value\n");CHKERRQ(ierr); }
   nep->mpd = nep->nev;
   if (nep->ncv>nep->nev+nep->mpd) SETERRQ(PetscObjectComm((PetscObject)nep),1,"The value of ncv must not be larger than nev+mpd");
-  if (!nep->max_it) nep->max_it = PetscMax(5000,2*nep->n/nep->ncv);
+  if (nep->max_it==PETSC_DEFAULT) nep->max_it = PetscMax(5000,2*nep->n/nep->ncv);
   if (nep->which && nep->which!=NEP_TARGET_MAGNITUDE) SETERRQ(PetscObjectComm((PetscObject)nep),1,"Wrong value of which");
 
   ierr = RGIsTrivial(nep->rg,&istrivial);CHKERRQ(ierr);
@@ -60,16 +56,29 @@ PetscErrorCode NEPSetUp_SLP(NEP nep)
   if (flg) SETERRQ(PetscObjectComm((PetscObject)nep),1,"SLP does not support spectral transformation");
   ierr = EPSSetDimensions(ctx->eps,1,PETSC_DECIDE,PETSC_DECIDE);CHKERRQ(ierr);
   ierr = EPSSetWhichEigenpairs(ctx->eps,EPS_LARGEST_MAGNITUDE);CHKERRQ(ierr);
-  ierr = EPSSetTolerances(ctx->eps,nep->tol==PETSC_DEFAULT?SLEPC_DEFAULT_TOL/10.0:nep->tol/10.0,nep->max_it?nep->max_it:PETSC_DEFAULT);CHKERRQ(ierr);
-
+  ierr = EPSSetTolerances(ctx->eps,nep->tol==PETSC_DEFAULT?SLEPC_DEFAULT_TOL/10.0:nep->tol/10.0,nep->max_it);CHKERRQ(ierr);
+  if (nep->twosided) {
+    nep->ops->solve = NEPSolve_SLP_Twosided;
+    nep->ops->computevectors = NULL;
+    if (!ctx->epsts) { ierr = NEPSLPGetEPSLeft(nep,&ctx->epsts);CHKERRQ(ierr); }
+    ierr = EPSGetST(ctx->epsts,&st);CHKERRQ(ierr);
+    ierr = PetscObjectTypeCompareAny((PetscObject)st,&flg,STSINVERT,STCAYLEY,"");CHKERRQ(ierr);
+    if (flg) SETERRQ(PetscObjectComm((PetscObject)nep),1,"SLP does not support spectral transformation");
+    ierr = EPSSetDimensions(ctx->epsts,1,PETSC_DECIDE,PETSC_DECIDE);CHKERRQ(ierr);
+    ierr = EPSSetWhichEigenpairs(ctx->epsts,EPS_LARGEST_MAGNITUDE);CHKERRQ(ierr);
+    ierr = EPSSetTolerances(ctx->epsts,nep->tol==PETSC_DEFAULT?SLEPC_DEFAULT_TOL/10.0:nep->tol/10.0,nep->max_it);CHKERRQ(ierr);
+  } else {
+    nep->ops->solve = NEPSolve_SLP;
+    nep->ops->computevectors = NEPComputeVectors_Schur;
+  }
   ierr = NEPAllocateSolution(nep,0);CHKERRQ(ierr);
   PetscFunctionReturn(0);
 }
 
-PetscErrorCode NEPSLPEPSMatShell_MatMult(Mat M,Vec x,Vec y)
+static PetscErrorCode MatMult_SLP(Mat M,Vec x,Vec y)
 {
-  PetscErrorCode     ierr;
-  NEP_SLP_EPS_MSHELL *ctx;
+  PetscErrorCode   ierr;
+  NEP_SLP_MATSHELL *ctx;
 
   PetscFunctionBegin;
   ierr = MatShellGetContext(M,(void**)&ctx);CHKERRQ(ierr);
@@ -78,10 +87,10 @@ PetscErrorCode NEPSLPEPSMatShell_MatMult(Mat M,Vec x,Vec y)
   PetscFunctionReturn(0);
 }
 
-PetscErrorCode NEPSLPEPSMatShell_Destroy(Mat M)
+static PetscErrorCode MatDestroy_SLP(Mat M)
 {
-  PetscErrorCode     ierr;
-  NEP_SLP_EPS_MSHELL *ctx;
+  PetscErrorCode   ierr;
+  NEP_SLP_MATSHELL *ctx;
 
   PetscFunctionBegin;
   ierr = MatShellGetContext(M,(void**)&ctx);CHKERRQ(ierr);
@@ -90,10 +99,11 @@ PetscErrorCode NEPSLPEPSMatShell_Destroy(Mat M)
   PetscFunctionReturn(0);
 }
 
-PetscErrorCode NEPSLPEPSMatShell_CreateVecs(Mat M,Vec *left,Vec *right)
+#if defined(PETSC_HAVE_CUDA)
+static PetscErrorCode MatCreateVecs_SLP(Mat M,Vec *left,Vec *right)
 {
-  PetscErrorCode     ierr;
-  NEP_SLP_EPS_MSHELL *ctx;
+  PetscErrorCode   ierr;
+  NEP_SLP_MATSHELL *ctx;
 
   PetscFunctionBegin;
   ierr = MatShellGetContext(M,(void**)&ctx);CHKERRQ(ierr);
@@ -105,14 +115,15 @@ PetscErrorCode NEPSLPEPSMatShell_CreateVecs(Mat M,Vec *left,Vec *right)
   }
   PetscFunctionReturn(0);
 }
+#endif
 
 static PetscErrorCode NEPSLPSetUpLinearEP(NEP nep,NEP_EXT_OP extop,PetscScalar lambda,Vec u,PetscBool ini)
 {
-  PetscErrorCode     ierr;
-  NEP_SLP            *slpctx = (NEP_SLP*)nep->data;
-  Mat                Mshell;
-  PetscInt           nloc,mloc;
-  NEP_SLP_EPS_MSHELL *shellctx;
+  PetscErrorCode   ierr;
+  NEP_SLP          *slpctx = (NEP_SLP*)nep->data;
+  Mat              Mshell;
+  PetscInt         nloc,mloc;
+  NEP_SLP_MATSHELL *shellctx;
 
   PetscFunctionBegin;
   if (ini) {
@@ -123,9 +134,11 @@ static PetscErrorCode NEPSLPSetUpLinearEP(NEP nep,NEP_EXT_OP extop,PetscScalar l
     ierr = MatGetLocalSize(nep->function,&mloc,&nloc);CHKERRQ(ierr);
     nloc += extop->szd; mloc += extop->szd;
     ierr = MatCreateShell(PetscObjectComm((PetscObject)nep),nloc,mloc,PETSC_DETERMINE,PETSC_DETERMINE,shellctx,&Mshell);CHKERRQ(ierr);
-    ierr = MatShellSetOperation(Mshell,MATOP_MULT,(void(*)(void))NEPSLPEPSMatShell_MatMult);CHKERRQ(ierr);
-    ierr = MatShellSetOperation(Mshell,MATOP_DESTROY,(void(*)(void))NEPSLPEPSMatShell_Destroy);CHKERRQ(ierr);
-    ierr = MatShellSetOperation(Mshell,MATOP_CREATE_VECS,(void(*)(void))NEPSLPEPSMatShell_CreateVecs);CHKERRQ(ierr);
+    ierr = MatShellSetOperation(Mshell,MATOP_MULT,(void(*)(void))MatMult_SLP);CHKERRQ(ierr);
+    ierr = MatShellSetOperation(Mshell,MATOP_DESTROY,(void(*)(void))MatDestroy_SLP);CHKERRQ(ierr);
+#if defined(PETSC_HAVE_CUDA)
+    ierr = MatShellSetOperation(Mshell,MATOP_CREATE_VECS,(void(*)(void))MatCreateVecs_SLP);CHKERRQ(ierr);
+#endif
     ierr = EPSSetOperators(slpctx->eps,Mshell,NULL);CHKERRQ(ierr);
     ierr = MatDestroy(&Mshell);CHKERRQ(ierr);
   }
@@ -144,7 +157,7 @@ PetscErrorCode NEPSolve_SLP(NEP nep)
   PetscScalar    sigma,lambda,mu,im,*Hp,*Ap;
   PetscReal      resnorm;
   PetscInt       nconv,ldh,ldds,i,j;
-  PetscBool      skip=PETSC_FALSE;
+  PetscBool      skip=PETSC_FALSE,lock=PETSC_FALSE;
   NEP_EXT_OP     extop=NULL;    /* Extended operator for deflation */
 
   PetscFunctionBegin;
@@ -174,9 +187,22 @@ PetscErrorCode NEPSolve_SLP(NEP nep)
     ierr = VecNorm(r,NORM_2,&resnorm);CHKERRQ(ierr);
     ierr = (*nep->converged)(nep,lambda,0,resnorm,&nep->errest[nep->nconv],nep->convergedctx);CHKERRQ(ierr);
     nep->eigr[nep->nconv] = lambda;
-    if (nep->errest[nep->nconv]<=nep->tol) {
+    if (nep->errest[nep->nconv]<=nep->tol || nep->errest[nep->nconv]<=ctx->deftol) {
+      if (nep->errest[nep->nconv]<=ctx->deftol && !extop->ref && nep->nconv) {
+        ierr = NEPDeflationExtractEigenpair(extop,nep->nconv,u,lambda,nep->ds);CHKERRQ(ierr);
+        ierr = NEPDeflationSetRefine(extop,PETSC_TRUE);CHKERRQ(ierr);
+        ierr = MatMult(F,u,r);CHKERRQ(ierr);
+        ierr = VecNorm(r,NORM_2,&resnorm);CHKERRQ(ierr);
+        ierr = (*nep->converged)(nep,lambda,0,resnorm,&nep->errest[nep->nconv],nep->convergedctx);CHKERRQ(ierr);
+        if (nep->errest[nep->nconv]<=nep->tol) lock = PETSC_TRUE;
+      } else if (nep->errest[nep->nconv]<=nep->tol) lock = PETSC_TRUE;
+    }
+
+    if (lock) {
+      ierr = NEPDeflationSetRefine(extop,PETSC_FALSE);CHKERRQ(ierr);
       nep->nconv = nep->nconv + 1;
       skip = PETSC_TRUE;
+      lock = PETSC_FALSE;
       ierr = NEPDeflationLocking(extop,u,lambda);CHKERRQ(ierr);
     }
     ierr = (*nep->stopping)(nep,nep->its,nep->max_it,nep->nconv,nep->nev,&nep->reason,nep->stoppingctx);CHKERRQ(ierr);
@@ -218,6 +244,7 @@ PetscErrorCode NEPSolve_SLP(NEP nep)
   }
   ierr = NEPDeflationGetInvariantPair(extop,NULL,&H);CHKERRQ(ierr);
   ierr = MatGetSize(H,NULL,&ldh);CHKERRQ(ierr);
+  ierr = DSReset(nep->ds);CHKERRQ(ierr);
   ierr = DSSetType(nep->ds,DSNHEP);CHKERRQ(ierr);
   ierr = DSAllocate(nep->ds,PetscMax(nep->nconv,1));CHKERRQ(ierr);
   ierr = DSGetLeadingDimension(nep->ds,&ldds);CHKERRQ(ierr);
@@ -240,18 +267,109 @@ PetscErrorCode NEPSetFromOptions_SLP(PetscOptionItems *PetscOptionsObject,NEP ne
 {
   PetscErrorCode ierr;
   NEP_SLP        *ctx = (NEP_SLP*)nep->data;
+  PetscBool      flg;
+  PetscReal      r;
 
   PetscFunctionBegin;
   ierr = PetscOptionsHead(PetscOptionsObject,"NEP SLP Options");CHKERRQ(ierr);
+
+    r = 0.0;
+    ierr = PetscOptionsReal("-nep_slp_deflation_threshold","Tolerance used as a threshold for including deflated eigenpairs","NEPSLPSetDeflationThreshold",ctx->deftol,&r,&flg);CHKERRQ(ierr);
+    if (flg) { ierr = NEPSLPSetDeflationThreshold(nep,r);CHKERRQ(ierr); }
+
   ierr = PetscOptionsTail();CHKERRQ(ierr);
 
   if (!ctx->eps) { ierr = NEPSLPGetEPS(nep,&ctx->eps);CHKERRQ(ierr); }
   ierr = EPSSetFromOptions(ctx->eps);CHKERRQ(ierr);
+  if (nep->twosided) {
+    if (!ctx->epsts) { ierr = NEPSLPGetEPSLeft(nep,&ctx->epsts);CHKERRQ(ierr); }
+    ierr = EPSSetFromOptions(ctx->epsts);CHKERRQ(ierr);
+  }
   if (!ctx->ksp) { ierr = NEPSLPGetKSP(nep,&ctx->ksp);CHKERRQ(ierr); }
   ierr = KSPSetFromOptions(ctx->ksp);CHKERRQ(ierr);
   PetscFunctionReturn(0);
 }
 
+static PetscErrorCode NEPSLPSetDeflationThreshold_SLP(NEP nep,PetscReal deftol)
+{
+  NEP_SLP *ctx = (NEP_SLP*)nep->data;
+
+  PetscFunctionBegin;
+  ctx->deftol = deftol;
+  PetscFunctionReturn(0);
+}
+
+/*@
+   NEPSLPSetDeflationThreshold - Sets the threshold value used to switch between
+   deflated and non-deflated iteration.
+
+   Logically Collective on nep
+
+   Input Parameters:
++  nep    - nonlinear eigenvalue solver
+-  deftol - the threshold value
+
+   Options Database Keys:
+.  -nep_slp_deflation_threshold <deftol> - set the threshold
+
+   Notes:
+   Normally, the solver iterates on the extended problem in order to deflate
+   previously converged eigenpairs. If this threshold is set to a nonzero value,
+   then once the residual error is below this threshold the solver will
+   continue the iteration without deflation. The intention is to be able to
+   improve the current eigenpair further, despite having previous eigenpairs
+   with somewhat bad precision.
+
+   Level: advanced
+
+.seealso: NEPSLPGetDeflationThreshold()
+@*/
+PetscErrorCode NEPSLPSetDeflationThreshold(NEP nep,PetscReal deftol)
+{
+  PetscErrorCode ierr;
+
+  PetscFunctionBegin;
+  PetscValidHeaderSpecific(nep,NEP_CLASSID,1);
+  PetscValidLogicalCollectiveReal(nep,deftol,2);
+  ierr = PetscTryMethod(nep,"NEPSLPSetDeflationThreshold_C",(NEP,PetscReal),(nep,deftol));CHKERRQ(ierr);
+  PetscFunctionReturn(0);
+}
+
+static PetscErrorCode NEPSLPGetDeflationThreshold_SLP(NEP nep,PetscReal *deftol)
+{
+  NEP_SLP *ctx = (NEP_SLP*)nep->data;
+
+  PetscFunctionBegin;
+  *deftol = ctx->deftol;
+  PetscFunctionReturn(0);
+}
+
+/*@
+   NEPSLPGetDeflationThreshold - Returns the threshold value that controls deflation.
+
+   Not Collective
+
+   Input Parameter:
+.  nep - nonlinear eigenvalue solver
+
+   Output Parameter:
+.  deftol - the threshold
+
+   Level: advanced
+
+.seealso: NEPSLPSetDeflationThreshold()
+@*/
+PetscErrorCode NEPSLPGetDeflationThreshold(NEP nep,PetscReal *deftol)
+{
+  PetscErrorCode ierr;
+
+  PetscFunctionBegin;
+  PetscValidHeaderSpecific(nep,NEP_CLASSID,1);
+  PetscValidBoolPointer(deftol,2);
+  ierr = PetscUseMethod(nep,"NEPSLPGetDeflationThreshold_C",(NEP,PetscReal*),(nep,deftol));CHKERRQ(ierr);
+  PetscFunctionReturn(0);
+}
+
 static PetscErrorCode NEPSLPSetEPS_SLP(NEP nep,EPS eps)
 {
   PetscErrorCode ierr;
@@ -337,6 +455,93 @@ PetscErrorCode NEPSLPGetEPS(NEP nep,EPS *eps)
   PetscFunctionReturn(0);
 }
 
+static PetscErrorCode NEPSLPSetEPSLeft_SLP(NEP nep,EPS eps)
+{
+  PetscErrorCode ierr;
+  NEP_SLP        *ctx = (NEP_SLP*)nep->data;
+
+  PetscFunctionBegin;
+  ierr = PetscObjectReference((PetscObject)eps);CHKERRQ(ierr);
+  ierr = EPSDestroy(&ctx->epsts);CHKERRQ(ierr);
+  ctx->epsts = eps;
+  ierr = PetscLogObjectParent((PetscObject)nep,(PetscObject)ctx->epsts);CHKERRQ(ierr);
+  nep->state = NEP_STATE_INITIAL;
+  PetscFunctionReturn(0);
+}
+
+/*@
+   NEPSLPSetEPSLeft - Associate a linear eigensolver object (EPS) to the
+   nonlinear eigenvalue solver, used to compute left eigenvectors in the
+   two-sided variant of SLP.
+
+   Collective on nep
+
+   Input Parameters:
++  nep - nonlinear eigenvalue solver
+-  eps - the eigensolver object
+
+   Level: advanced
+
+.seealso: NEPSLPGetEPSLeft(), NEPSetTwoSided()
+@*/
+PetscErrorCode NEPSLPSetEPSLeft(NEP nep,EPS eps)
+{
+  PetscErrorCode ierr;
+
+  PetscFunctionBegin;
+  PetscValidHeaderSpecific(nep,NEP_CLASSID,1);
+  PetscValidHeaderSpecific(eps,EPS_CLASSID,2);
+  PetscCheckSameComm(nep,1,eps,2);
+  ierr = PetscTryMethod(nep,"NEPSLPSetEPSLeft_C",(NEP,EPS),(nep,eps));CHKERRQ(ierr);
+  PetscFunctionReturn(0);
+}
+
+static PetscErrorCode NEPSLPGetEPSLeft_SLP(NEP nep,EPS *eps)
+{
+  PetscErrorCode ierr;
+  NEP_SLP        *ctx = (NEP_SLP*)nep->data;
+
+  PetscFunctionBegin;
+  if (!ctx->epsts) {
+    ierr = EPSCreate(PetscObjectComm((PetscObject)nep),&ctx->epsts);CHKERRQ(ierr);
+    ierr = PetscObjectIncrementTabLevel((PetscObject)ctx->epsts,(PetscObject)nep,1);CHKERRQ(ierr);
+    ierr = EPSSetOptionsPrefix(ctx->epsts,((PetscObject)nep)->prefix);CHKERRQ(ierr);
+    ierr = EPSAppendOptionsPrefix(ctx->epsts,"nep_slp_left_");CHKERRQ(ierr);
+    ierr = PetscLogObjectParent((PetscObject)nep,(PetscObject)ctx->epsts);CHKERRQ(ierr);
+    ierr = PetscObjectSetOptions((PetscObject)ctx->epsts,((PetscObject)nep)->options);CHKERRQ(ierr);
+  }
+  *eps = ctx->epsts;
+  PetscFunctionReturn(0);
+}
+
+/*@
+   NEPSLPGetEPSLeft - Retrieve the linear eigensolver object (EPS) associated
+   to the nonlinear eigenvalue solver, used to compute left eigenvectors in the
+   two-sided variant of SLP.
+
+   Not Collective
+
+   Input Parameter:
+.  nep - nonlinear eigenvalue solver
+
+   Output Parameter:
+.  eps - the eigensolver object
+
+   Level: advanced
+
+.seealso: NEPSLPSetEPSLeft(), NEPSetTwoSided()
+@*/
+PetscErrorCode NEPSLPGetEPSLeft(NEP nep,EPS *eps)
+{
+  PetscErrorCode ierr;
+
+  PetscFunctionBegin;
+  PetscValidHeaderSpecific(nep,NEP_CLASSID,1);
+  PetscValidPointer(eps,2);
+  ierr = PetscUseMethod(nep,"NEPSLPGetEPSLeft_C",(NEP,EPS*),(nep,eps));CHKERRQ(ierr);
+  PetscFunctionReturn(0);
+}
+
 static PetscErrorCode NEPSLPSetKSP_SLP(NEP nep,KSP ksp)
 {
   PetscErrorCode ierr;
@@ -432,9 +637,16 @@ PetscErrorCode NEPView_SLP(NEP nep,PetscViewer viewer)
   PetscFunctionBegin;
   ierr = PetscObjectTypeCompare((PetscObject)viewer,PETSCVIEWERASCII,&isascii);CHKERRQ(ierr);
   if (isascii) {
+    if (ctx->deftol) {
+      ierr = PetscViewerASCIIPrintf(viewer,"  deflation threshold: %g\n",(double)ctx->deftol);CHKERRQ(ierr);
+    }
     if (!ctx->eps) { ierr = NEPSLPGetEPS(nep,&ctx->eps);CHKERRQ(ierr); }
     ierr = PetscViewerASCIIPushTab(viewer);CHKERRQ(ierr);
     ierr = EPSView(ctx->eps,viewer);CHKERRQ(ierr);
+    if (nep->twosided) {
+      if (!ctx->epsts) { ierr = NEPSLPGetEPSLeft(nep,&ctx->epsts);CHKERRQ(ierr); }
+      ierr = EPSView(ctx->epsts,viewer);CHKERRQ(ierr);
+    }
     if (!ctx->ksp) { ierr = NEPSLPGetKSP(nep,&ctx->ksp);CHKERRQ(ierr); }
     ierr = KSPView(ctx->ksp,viewer);CHKERRQ(ierr);
     ierr = PetscViewerASCIIPopTab(viewer);CHKERRQ(ierr);
@@ -449,6 +661,7 @@ PetscErrorCode NEPReset_SLP(NEP nep)
 
   PetscFunctionBegin;
   ierr = EPSReset(ctx->eps);CHKERRQ(ierr);
+  if (nep->twosided) { ierr = EPSReset(ctx->epsts);CHKERRQ(ierr); }
   ierr = KSPReset(ctx->ksp);CHKERRQ(ierr);
   PetscFunctionReturn(0);
 }
@@ -461,9 +674,14 @@ PetscErrorCode NEPDestroy_SLP(NEP nep)
   PetscFunctionBegin;
   ierr = KSPDestroy(&ctx->ksp);CHKERRQ(ierr);
   ierr = EPSDestroy(&ctx->eps);CHKERRQ(ierr);
+  ierr = EPSDestroy(&ctx->epsts);CHKERRQ(ierr);
   ierr = PetscFree(nep->data);CHKERRQ(ierr);
+  ierr = PetscObjectComposeFunction((PetscObject)nep,"NEPSLPSetDeflationThreshold_C",NULL);CHKERRQ(ierr);
+  ierr = PetscObjectComposeFunction((PetscObject)nep,"NEPSLPGetDeflationThreshold_C",NULL);CHKERRQ(ierr);
   ierr = PetscObjectComposeFunction((PetscObject)nep,"NEPSLPSetEPS_C",NULL);CHKERRQ(ierr);
   ierr = PetscObjectComposeFunction((PetscObject)nep,"NEPSLPGetEPS_C",NULL);CHKERRQ(ierr);
+  ierr = PetscObjectComposeFunction((PetscObject)nep,"NEPSLPSetEPSLeft_C",NULL);CHKERRQ(ierr);
+  ierr = PetscObjectComposeFunction((PetscObject)nep,"NEPSLPGetEPSLeft_C",NULL);CHKERRQ(ierr);
   ierr = PetscObjectComposeFunction((PetscObject)nep,"NEPSLPSetKSP_C",NULL);CHKERRQ(ierr);
   ierr = PetscObjectComposeFunction((PetscObject)nep,"NEPSLPGetKSP_C",NULL);CHKERRQ(ierr);
   PetscFunctionReturn(0);
@@ -479,6 +697,9 @@ SLEPC_EXTERN PetscErrorCode NEPCreate_SLP(NEP nep)
   nep->data = (void*)ctx;
 
   nep->useds = PETSC_TRUE;
+  nep->hasts = PETSC_TRUE;
+
+  ctx->deftol = 0.0;
 
   nep->ops->solve          = NEPSolve_SLP;
   nep->ops->setup          = NEPSetUp_SLP;
@@ -488,8 +709,12 @@ SLEPC_EXTERN PetscErrorCode NEPCreate_SLP(NEP nep)
   nep->ops->view           = NEPView_SLP;
   nep->ops->computevectors = NEPComputeVectors_Schur;
 
+  ierr = PetscObjectComposeFunction((PetscObject)nep,"NEPSLPSetDeflationThreshold_C",NEPSLPSetDeflationThreshold_SLP);CHKERRQ(ierr);
+  ierr = PetscObjectComposeFunction((PetscObject)nep,"NEPSLPGetDeflationThreshold_C",NEPSLPGetDeflationThreshold_SLP);CHKERRQ(ierr);
   ierr = PetscObjectComposeFunction((PetscObject)nep,"NEPSLPSetEPS_C",NEPSLPSetEPS_SLP);CHKERRQ(ierr);
   ierr = PetscObjectComposeFunction((PetscObject)nep,"NEPSLPGetEPS_C",NEPSLPGetEPS_SLP);CHKERRQ(ierr);
+  ierr = PetscObjectComposeFunction((PetscObject)nep,"NEPSLPSetEPSLeft_C",NEPSLPSetEPSLeft_SLP);CHKERRQ(ierr);
+  ierr = PetscObjectComposeFunction((PetscObject)nep,"NEPSLPGetEPSLeft_C",NEPSLPGetEPSLeft_SLP);CHKERRQ(ierr);
   ierr = PetscObjectComposeFunction((PetscObject)nep,"NEPSLPSetKSP_C",NEPSLPSetKSP_SLP);CHKERRQ(ierr);
   ierr = PetscObjectComposeFunction((PetscObject)nep,"NEPSLPGetKSP_C",NEPSLPGetKSP_SLP);CHKERRQ(ierr);
   PetscFunctionReturn(0);
