@@ -1,7 +1,7 @@
 /*
    - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
    SLEPc - Scalable Library for Eigenvalue Problem Computations
-   Copyright (c) 2002-2019, Universitat Politecnica de Valencia, Spain
+   Copyright (c) 2002-2020, Universitat Politecnica de Valencia, Spain
 
    This file is part of SLEPc.
    SLEPc is distributed under a 2-clause BSD license (see LICENSE).
@@ -19,8 +19,8 @@
    References:
 
        [1] C. Campos and J.E. Roman, "Inertia-based spectrum slicing
-           for symmetric quadratic eigenvalue problems", submitted,
-           2019.
+           for symmetric quadratic eigenvalue problems", Numer. Linear
+           Algebra Appl. (in press), 2020.
 */
 
 #include <slepc/private/pepimpl.h>         /*I "slepcpep.h" I*/
@@ -32,12 +32,12 @@ static const char citation[] =
   "@Article{slepc-slice-qep,\n"
   "   author = \"C. Campos and J. E. Roman\",\n"
   "   title = \"Inertia-based spectrum slicing for symmetric quadratic eigenvalue problems\",\n"
-  "   journal = \"Submitted\",\n"
-  "   volume = \"xx\",\n"
+  "   journal = \"Numer. Linear Algebra Appl.\",\n"
+  "   volume = \"IP\",\n"
   "   number = \"x\",\n"
   "   pages = \"xx--xx\",\n"
-  "   year = \"2019,\"\n"
-  "   doi = \"https://doi.org/10.1007/xxx\"\n"
+  "   year = \"2020,\"\n"
+  "   doi = \"https://doi.org/10.1002/nla.2293\"\n"
   "}\n";
 
 #define SLICE_PTOL PETSC_SQRT_MACHINE_EPSILON
@@ -153,7 +153,6 @@ static PetscErrorCode PEPQSliceMatGetInertia(PEP pep,PetscReal shift,PetscInt *i
   } else {
     ierr = PEPEvaluateBasis(pep,shift,0,pep->solvematcoeffs,NULL);CHKERRQ(ierr);
   }
-  ierr = STSetUp(pep->st);CHKERRQ(ierr);
   ierr = STMatSetUp(pep->st,pep->sfactor,pep->solvematcoeffs);CHKERRQ(ierr);
   ierr = STGetKSP(pep->st,&ksp);CHKERRQ(ierr);
   ierr = KSPGetPC(ksp,&pc);CHKERRQ(ierr);
@@ -372,7 +371,7 @@ PetscErrorCode PEPCheckDefiniteQEP(PEP pep,PetscReal *xi,PetscReal *mu,PetscInt
   PetscErrorCode ierr;
   PetscRandom    rand;
   Vec            u,w;
-  PetscReal      d,s=0.0,sp,mut=0.0,omg=0.0,omgp;
+  PetscReal      d=0.0,s=0.0,sp,mut=0.0,omg=0.0,omgp;
   PetscInt       k,its=10,hyp=0,check=0,nconv,inertia,n;
   Mat            M=NULL;
   MatStructure   str;
@@ -514,7 +513,7 @@ PetscErrorCode PEPSetUp_STOAR_QSlice(PEP pep)
   if (ctx->nev==1) ctx->nev = PetscMin(20,pep->n);  /* nev not set, use default value */
   if (pep->n>10 && ctx->nev<10) SETERRQ(PetscObjectComm((PetscObject)pep),PETSC_ERR_ARG_WRONG,"nev cannot be less than 10 in spectrum slicing runs");
   pep->ops->backtransform = PEPBackTransform_Skip;
-  if (!pep->max_it) pep->max_it = 100;
+  if (pep->max_it==PETSC_DEFAULT) pep->max_it = 100;
 
   /* create spectrum slicing context and initialize it */
   ierr = PEPQSliceResetSR(pep);CHKERRQ(ierr);
@@ -1127,6 +1126,7 @@ static PetscErrorCode PEPSTOAR_QSlice(PEP pep,Mat B)
   ierr = DSGetLeadingDimension(pep->ds,&ldds);CHKERRQ(ierr);
   ierr = BVSetMatrix(ctx->V,B,PETSC_TRUE);CHKERRQ(ierr);
   if (ctx->lock) {
+    /* undocumented option to use a cheaper locking instead of the true locking */
     ierr = PetscOptionsGetBool(NULL,NULL,"-pep_stoar_falselocking",&falselock,NULL);CHKERRQ(ierr);
   } else SETERRQ(PetscObjectComm((PetscObject)pep),PETSC_ERR_SUP,"A locking variant is needed for spectrum slicing");
   ierr = PetscObjectTypeCompare((PetscObject)pep->st,STSINVERT,&sinv);CHKERRQ(ierr);
