@@ -1,7 +1,7 @@
 /*
    - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
    SLEPc - Scalable Library for Eigenvalue Problem Computations
-   Copyright (c) 2002-2019, Universitat Politecnica de Valencia, Spain
+   Copyright (c) 2002-2020, Universitat Politecnica de Valencia, Spain
 
    This file is part of SLEPc.
    SLEPc is distributed under a 2-clause BSD license (see LICENSE).
@@ -44,12 +44,12 @@ typedef struct {
   PetscReal   scal[2];
   Mat         A[2];
   Vec         t;
-} ShellMatCtx;
+} PEP_STOAR_MATSHELL;
 
-PetscErrorCode MatMult_Func(Mat A,Vec x,Vec y)
+static PetscErrorCode MatMult_STOAR(Mat A,Vec x,Vec y)
 {
-  PetscErrorCode ierr;
-  ShellMatCtx    *ctx;
+  PetscErrorCode     ierr;
+  PEP_STOAR_MATSHELL *ctx;
 
   PetscFunctionBegin;
   ierr = MatShellGetContext(A,&ctx);CHKERRQ(ierr);
@@ -62,10 +62,10 @@ PetscErrorCode MatMult_Func(Mat A,Vec x,Vec y)
   PetscFunctionReturn(0);
 }
 
-PetscErrorCode MatDestroy_Func(Mat A)
+static PetscErrorCode MatDestroy_STOAR(Mat A)
 {
-  ShellMatCtx    *ctx;
-  PetscErrorCode ierr;
+  PEP_STOAR_MATSHELL *ctx;
+  PetscErrorCode     ierr;
 
   PetscFunctionBegin;
   ierr = MatShellGetContext(A,(void**)&ctx);CHKERRQ(ierr);
@@ -76,11 +76,11 @@ PetscErrorCode MatDestroy_Func(Mat A)
 
 PetscErrorCode PEPSTOARSetUpInnerMatrix(PEP pep,Mat *B)
 {
-  Mat            pB[4],Bs[3],D[3];
-  PetscInt       i,j,n,m;
-  ShellMatCtx    *ctxMat[3];
-  PEP_STOAR      *ctx=(PEP_STOAR*)pep->data;
-  PetscErrorCode ierr;
+  Mat                pB[4],Bs[3],D[3];
+  PetscInt           i,j,n,m;
+  PEP_STOAR_MATSHELL *ctxMat[3];
+  PEP_STOAR          *ctx=(PEP_STOAR*)pep->data;
+  PetscErrorCode     ierr;
 
   PetscFunctionBegin;
   for (i=0;i<3;i++) {
@@ -91,8 +91,8 @@ PetscErrorCode PEPSTOARSetUpInnerMatrix(PEP pep,Mat *B)
   for (j=0;j<3;j++) {
     ierr = PetscNew(ctxMat+j);CHKERRQ(ierr);
     ierr = MatCreateShell(PetscObjectComm((PetscObject)pep),m,n,PETSC_DETERMINE,PETSC_DETERMINE,ctxMat[j],&Bs[j]);CHKERRQ(ierr);
-    ierr = MatShellSetOperation(Bs[j],MATOP_MULT,(void(*)(void))MatMult_Func);CHKERRQ(ierr);
-    ierr = MatShellSetOperation(Bs[j],MATOP_DESTROY,(void(*)(void))MatDestroy_Func);CHKERRQ(ierr);
+    ierr = MatShellSetOperation(Bs[j],MATOP_MULT,(void(*)(void))MatMult_STOAR);CHKERRQ(ierr);
+    ierr = MatShellSetOperation(Bs[j],MATOP_DESTROY,(void(*)(void))MatDestroy_STOAR);CHKERRQ(ierr);
   }
   for (i=0;i<4;i++) pB[i] = NULL;
   if (ctx->alpha) {
@@ -138,7 +138,7 @@ PetscErrorCode PEPSetUp_STOAR(PEP pep)
   } else {
     ierr = PEPSetDimensions_Default(pep,pep->nev,&pep->ncv,&pep->mpd);CHKERRQ(ierr);
     if (!ctx->lock && pep->mpd<pep->ncv) SETERRQ(PetscObjectComm((PetscObject)pep),PETSC_ERR_SUP,"Should not use mpd parameter in non-locking variant");
-    if (!pep->max_it) pep->max_it = PetscMax(100,2*(pep->nmat-1)*pep->n/pep->ncv);
+    if (pep->max_it==PETSC_DEFAULT) pep->max_it = PetscMax(100,2*(pep->nmat-1)*pep->n/pep->ncv);
     pep->ops->solve = PEPSolve_STOAR;
     ld   = pep->ncv+2;
     ierr = DSSetType(pep->ds,DSGHIEP);CHKERRQ(ierr);
@@ -341,6 +341,7 @@ PetscErrorCode PEPSolve_STOAR(PEP pep)
   ierr = BVSetMatrix(ctx->V,A,PETSC_TRUE);CHKERRQ(ierr);
   ierr = MatDestroy(&A);CHKERRQ(ierr);
   if (ctx->lock) {
+    /* undocumented option to use a cheaper locking instead of the true locking */
     ierr = PetscOptionsGetBool(NULL,NULL,"-pep_stoar_falselocking",&falselock,NULL);CHKERRQ(ierr);
   }
   ierr = BVGetSizes(pep->V,NULL,NULL,&ld);CHKERRQ(ierr);
@@ -904,13 +905,13 @@ static PetscErrorCode PEPSTOARSetDimensions_STOAR(PEP pep,PetscInt nev,PetscInt
   if (nev<1) SETERRQ(PetscObjectComm((PetscObject)pep),PETSC_ERR_ARG_OUTOFRANGE,"Illegal value of nev. Must be > 0");
   ctx->nev = nev;
   if (ncv == PETSC_DECIDE || ncv == PETSC_DEFAULT) {
-    ctx->ncv = 0;
+    ctx->ncv = PETSC_DEFAULT;
   } else {
     if (ncv<1) SETERRQ(PetscObjectComm((PetscObject)pep),PETSC_ERR_ARG_OUTOFRANGE,"Illegal value of ncv. Must be > 0");
     ctx->ncv = ncv;
   }
   if (mpd == PETSC_DECIDE || mpd == PETSC_DEFAULT) {
-    ctx->mpd = 0;
+    ctx->mpd = PETSC_DEFAULT;
   } else {
     if (mpd<1) SETERRQ(PetscObjectComm((PetscObject)pep),PETSC_ERR_ARG_OUTOFRANGE,"Illegal value of mpd. Must be > 0");
     ctx->mpd = mpd;
@@ -1139,6 +1140,8 @@ SLEPC_EXTERN PetscErrorCode PEPCreate_STOAR(PEP pep)
   pep->data = (void*)ctx;
   ctx->lock    = PETSC_TRUE;
   ctx->nev     = 1;
+  ctx->ncv     = PETSC_DEFAULT;
+  ctx->mpd     = PETSC_DEFAULT;
   ctx->alpha   = 1.0;
   ctx->beta    = 0.0;
   ctx->checket = PETSC_TRUE;
