@@ -1,7 +1,7 @@
 /*
    - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
    SLEPc - Scalable Library for Eigenvalue Problem Computations
-   Copyright (c) 2002-2019, Universitat Politecnica de Valencia, Spain
+   Copyright (c) 2002-2020, Universitat Politecnica de Valencia, Spain
 
    This file is part of SLEPc.
    SLEPc is distributed under a 2-clause BSD license (see LICENSE).
@@ -12,7 +12,7 @@
 */
 
 #include <slepc/private/pepimpl.h>         /*I "slepcpep.h" I*/
-#include "linearp.h"
+#include "linear.h"
 
 static PetscErrorCode MatMult_Linear_Shift(Mat M,Vec x,Vec y)
 {
@@ -391,8 +391,8 @@ PetscErrorCode PEPSetUp_Linear(PEP pep)
     }
     ierr = EPSSetWhichEigenpairs(ctx->eps,which);CHKERRQ(ierr);
 
-    ierr = EPSSetDimensions(ctx->eps,pep->nev,pep->ncv?pep->ncv:PETSC_DEFAULT,pep->mpd?pep->mpd:PETSC_DEFAULT);CHKERRQ(ierr);
-    ierr = EPSSetTolerances(ctx->eps,pep->tol==PETSC_DEFAULT?SLEPC_DEFAULT_TOL:pep->tol,pep->max_it?pep->max_it:PETSC_DEFAULT);CHKERRQ(ierr);
+    ierr = EPSSetDimensions(ctx->eps,pep->nev,pep->ncv,pep->mpd);CHKERRQ(ierr);
+    ierr = EPSSetTolerances(ctx->eps,pep->tol==PETSC_DEFAULT?SLEPC_DEFAULT_TOL:pep->tol,pep->max_it);CHKERRQ(ierr);
   }
   ierr = RGIsTrivial(pep->rg,&istrivial);CHKERRQ(ierr);
   if (!istrivial) {
@@ -416,13 +416,13 @@ PetscErrorCode PEPSetUp_Linear(PEP pep)
     for (i=0;i<deg;i++) {
       if (i<-pep->nini) {
         ierr = VecGetArray(pep->IS[i],&peparray);CHKERRQ(ierr);
-        ierr = PetscMemcpy(epsarray+i*pep->nloc,peparray,pep->nloc*sizeof(PetscScalar));CHKERRQ(ierr);
+        ierr = PetscArraycpy(epsarray+i*pep->nloc,peparray,pep->nloc);CHKERRQ(ierr);
         ierr = VecRestoreArray(pep->IS[i],&peparray);CHKERRQ(ierr);
       } else {
         if (!w) { ierr = VecDuplicate(pep->IS[0],&w);CHKERRQ(ierr); }
         ierr = VecSetRandom(w,NULL);CHKERRQ(ierr);
         ierr = VecGetArray(w,&peparray);CHKERRQ(ierr);
-        ierr = PetscMemcpy(epsarray+i*pep->nloc,peparray,pep->nloc*sizeof(PetscScalar));CHKERRQ(ierr);
+        ierr = PetscArraycpy(epsarray+i*pep->nloc,peparray,pep->nloc);CHKERRQ(ierr);
         ierr = VecRestoreArray(w,&peparray);CHKERRQ(ierr);
       }
     }
@@ -776,7 +776,7 @@ static PetscErrorCode PEPLinearSetLinearization_Linear(PEP pep,PetscReal alpha,P
    PEPLinearSetLinearization - Set the coefficients that define
    the linearization of a quadratic eigenproblem.
 
-   Logically Collective on PEP
+   Logically Collective on pep
 
    Input Parameters:
 +  pep   - polynomial eigenvalue solver
@@ -859,7 +859,7 @@ static PetscErrorCode PEPLinearSetExplicitMatrix_Linear(PEP pep,PetscBool explic
    PEPLinearSetExplicitMatrix - Indicate if the matrices A and B for the
    linearization of the problem must be built explicitly.
 
-   Logically Collective on PEP
+   Logically Collective on pep
 
    Input Parameters:
 +  pep      - polynomial eigenvalue solver
@@ -914,7 +914,7 @@ PetscErrorCode PEPLinearGetExplicitMatrix(PEP pep,PetscBool *explicitmatrix)
 
   PetscFunctionBegin;
   PetscValidHeaderSpecific(pep,PEP_CLASSID,1);
-  PetscValidPointer(explicitmatrix,2);
+  PetscValidBoolPointer(explicitmatrix,2);
   ierr = PetscUseMethod(pep,"PEPLinearGetExplicitMatrix_C",(PEP,PetscBool*),(pep,explicitmatrix));CHKERRQ(ierr);
   PetscFunctionReturn(0);
 }
@@ -938,7 +938,7 @@ static PetscErrorCode PEPLinearSetEPS_Linear(PEP pep,EPS eps)
    PEPLinearSetEPS - Associate an eigensolver object (EPS) to the
    polynomial eigenvalue solver.
 
-   Collective on PEP
+   Collective on pep
 
    Input Parameters:
 +  pep - polynomial eigenvalue solver
