@@ -1,7 +1,7 @@
 /*
    - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
    SLEPc - Scalable Library for Eigenvalue Problem Computations
-   Copyright (c) 2002-2019, Universitat Politecnica de Valencia, Spain
+   Copyright (c) 2002-2020, Universitat Politecnica de Valencia, Spain
 
    This file is part of SLEPc.
    SLEPc is distributed under a 2-clause BSD license (see LICENSE).
@@ -205,43 +205,33 @@ PetscErrorCode BVNorm_Local_Svec(BV bv,PetscInt j,NormType type,PetscReal *val)
 
 PetscErrorCode BVMatMult_Svec(BV V,Mat A,BV W)
 {
-  PetscErrorCode   ierr;
-  BV_SVEC          *v = (BV_SVEC*)V->data,*w = (BV_SVEC*)W->data;
-  PetscScalar      *pv,*pw;
-  PetscInt         j;
-  PetscBool        flg;
-  Mat              Vmat,Wmat,aux;
-  PetscObjectState Astate;
+  PetscErrorCode ierr;
+  PetscInt       j;
+  PetscBool      flg;
+  Mat            Vmat,Wmat;
+  Vec            vv,ww;
 
   PetscFunctionBegin;
   ierr = MatHasOperation(A,MATOP_MAT_MULT,&flg);CHKERRQ(ierr);
   if (V->vmm && flg) {
     ierr = BVGetMat(V,&Vmat);CHKERRQ(ierr);
     ierr = BVGetMat(W,&Wmat);CHKERRQ(ierr);
-    ierr = PetscObjectStateGet((PetscObject)A,&Astate);CHKERRQ(ierr);
-    if (V->Amult==A && V->Amultstate==Astate) {
-      ierr = MatMatMult(A,Vmat,MAT_REUSE_MATRIX,PETSC_DEFAULT,&Wmat);CHKERRQ(ierr);
-    } else {
-      ierr = MatMatMult(A,Vmat,MAT_INITIAL_MATRIX,PETSC_DEFAULT,&aux);CHKERRQ(ierr);
-      ierr = MatCopy(aux,Wmat,SAME_NONZERO_PATTERN);CHKERRQ(ierr);
-      ierr = MatDestroy(&aux);CHKERRQ(ierr);
-      V->Amult = A;
-      V->Amultstate = Astate;
-    }
+    ierr = MatProductCreateWithMat(A,Vmat,NULL,Wmat);CHKERRQ(ierr);
+    ierr = MatProductSetType(Wmat,MATPRODUCT_AB);CHKERRQ(ierr);
+    ierr = MatProductSetFromOptions(Wmat);CHKERRQ(ierr);
+    ierr = MatProductSymbolic(Wmat);CHKERRQ(ierr);
+    ierr = MatProductNumeric(Wmat);CHKERRQ(ierr);
+    ierr = MatProductClear(Wmat);CHKERRQ(ierr);
     ierr = BVRestoreMat(V,&Vmat);CHKERRQ(ierr);
     ierr = BVRestoreMat(W,&Wmat);CHKERRQ(ierr);
   } else {
-    ierr = VecGetArray(v->v,&pv);CHKERRQ(ierr);
-    ierr = VecGetArray(w->v,&pw);CHKERRQ(ierr);
     for (j=0;j<V->k-V->l;j++) {
-      ierr = VecPlaceArray(V->cv[1],pv+(V->nc+V->l+j)*V->n);CHKERRQ(ierr);
-      ierr = VecPlaceArray(W->cv[1],pw+(W->nc+W->l+j)*W->n);CHKERRQ(ierr);
-      ierr = MatMult(A,V->cv[1],W->cv[1]);CHKERRQ(ierr);
-      ierr = VecResetArray(V->cv[1]);CHKERRQ(ierr);
-      ierr = VecResetArray(W->cv[1]);CHKERRQ(ierr);
+      ierr = BVGetColumn(V,V->l+j,&vv);CHKERRQ(ierr);
+      ierr = BVGetColumn(W,W->l+j,&ww);CHKERRQ(ierr);
+      ierr = MatMult(A,vv,ww);CHKERRQ(ierr);
+      ierr = BVRestoreColumn(V,V->l+j,&vv);CHKERRQ(ierr);
+      ierr = BVRestoreColumn(W,W->l+j,&ww);CHKERRQ(ierr);
     }
-    ierr = VecRestoreArray(v->v,&pv);CHKERRQ(ierr);
-    ierr = VecRestoreArray(w->v,&pw);CHKERRQ(ierr);
   }
   PetscFunctionReturn(0);
 }
