@@ -1,7 +1,7 @@
 /*
    - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
    SLEPc - Scalable Library for Eigenvalue Problem Computations
-   Copyright (c) 2002-2019, Universitat Politecnica de Valencia, Spain
+   Copyright (c) 2002-2020, Universitat Politecnica de Valencia, Spain
 
    This file is part of SLEPc.
    SLEPc is distributed under a 2-clause BSD license (see LICENSE).
@@ -54,6 +54,7 @@ PetscErrorCode STSetType(ST st,STType type)
 
   ierr = PetscObjectTypeCompare((PetscObject)st,type,&match);CHKERRQ(ierr);
   if (match) PetscFunctionReturn(0);
+  STCheckNotSeized(st,1);
 
   ierr =  PetscFunctionListFind(STList,type,&r);CHKERRQ(ierr);
   if (!r) SETERRQ1(PetscObjectComm((PetscObject)st),PETSC_ERR_ARG_UNKNOWN_TYPE,"Unable to find requested ST type %s",type);
@@ -61,7 +62,8 @@ PetscErrorCode STSetType(ST st,STType type)
   if (st->ops->destroy) { ierr = (*st->ops->destroy)(st);CHKERRQ(ierr); }
   ierr = PetscMemzero(st->ops,sizeof(struct _STOps));CHKERRQ(ierr);
 
-  st->state = ST_STATE_INITIAL;
+  st->state   = ST_STATE_INITIAL;
+  st->opready = PETSC_FALSE;
   ierr = PetscObjectChangeTypeName((PetscObject)st,type);CHKERRQ(ierr);
   ierr = (*r)(st);CHKERRQ(ierr);
   PetscFunctionReturn(0);
@@ -109,7 +111,7 @@ PetscErrorCode STSetFromOptions(ST st)
   PetscErrorCode ierr;
   PetscScalar    s;
   char           type[256];
-  PetscBool      flg;
+  PetscBool      flg,bval;
   const char     *structure_list[3] = {"different","subset","same"};
   STMatMode      mode;
   MatStructure   mstr;
@@ -134,7 +136,8 @@ PetscErrorCode STSetFromOptions(ST st)
     ierr = PetscOptionsEList("-st_matstructure","Relation of the sparsity pattern of the matrices","STSetMatStructure",structure_list,3,structure_list[st->str],(PetscInt*)&mstr,&flg);CHKERRQ(ierr);
     if (flg) { ierr = STSetMatStructure(st,mstr);CHKERRQ(ierr); }
 
-    ierr = PetscOptionsBool("-st_transform","Whether transformed matrices are computed or not","STSetTransform",st->transform,&st->transform,&flg);CHKERRQ(ierr);
+    ierr = PetscOptionsBool("-st_transform","Whether transformed matrices are computed or not","STSetTransform",st->transform,&bval,&flg);CHKERRQ(ierr);
+    if (flg) { ierr = STSetTransform(st,bval);CHKERRQ(ierr); }
 
     if (st->ops->setfromoptions) {
       ierr = (*st->ops->setfromoptions)(PetscOptionsObject,st);CHKERRQ(ierr);
@@ -264,8 +267,10 @@ PetscErrorCode STSetMatMode(ST st,STMatMode mode)
   PetscValidHeaderSpecific(st,ST_CLASSID,1);
   PetscValidLogicalCollectiveEnum(st,mode,2);
   if (st->matmode != mode) {
+    STCheckNotSeized(st,1);
     st->matmode = mode;
-    st->state = ST_STATE_INITIAL;
+    st->state   = ST_STATE_INITIAL;
+    st->opready = PETSC_FALSE;
   }
   PetscFunctionReturn(0);
 }
@@ -325,7 +330,8 @@ PetscErrorCode STSetTransform(ST st,PetscBool flg)
   PetscValidLogicalCollectiveBool(st,flg,2);
   if (st->transform != flg) {
     st->transform = flg;
-    st->state = ST_STATE_INITIAL;
+    st->state     = ST_STATE_INITIAL;
+    st->opready   = PETSC_FALSE;
   }
   PetscFunctionReturn(0);
 }
